@@ -30,7 +30,7 @@ if (class_exists('PHP_CodeSniffer_DocGenerators_Generator', true) === false) {
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_DocGenerators_HTML extends PHP_CodeSniffer_DocGenerators_Generator
@@ -41,7 +41,7 @@ class PHP_CodeSniffer_DocGenerators_HTML extends PHP_CodeSniffer_DocGenerators_G
      * Generates the documentation for a standard.
      *
      * @return void
-     * @see processSniff()
+     * @see    processSniff()
      */
     public function generate()
     {
@@ -188,12 +188,12 @@ class PHP_CodeSniffer_DocGenerators_HTML extends PHP_CodeSniffer_DocGenerators_G
     {
         // Turn off errors so we don't get timezone warnings if people
         // don't have their timezone set.
-        error_reporting(0);
+        $errorLevel = error_reporting(0);
         echo '  <div class="tag-line">';
         echo 'Documentation generated on '.date('r');
-        echo ' by <a href="http://pear.php.net/package/PHP_CodeSniffer">PHP_CodeSniffer '.PHP_CodeSniffer::VERSION.'</a>';
+        echo ' by <a href="https://github.com/squizlabs/PHP_CodeSniffer">PHP_CodeSniffer '.PHP_CodeSniffer::VERSION.'</a>';
         echo '</div>'.PHP_EOL;
-        error_reporting(E_ALL | E_STRICT);
+        error_reporting($errorLevel);
 
         echo ' </body>'.PHP_EOL;
         echo '</html>'.PHP_EOL;
@@ -260,20 +260,20 @@ class PHP_CodeSniffer_DocGenerators_HTML extends PHP_CodeSniffer_DocGenerators_G
         $codeBlocks = $node->getElementsByTagName('code');
 
         $firstTitle = $codeBlocks->item(0)->getAttribute('title');
-        $first = trim($codeBlocks->item(0)->nodeValue);
-        $first = str_replace('<?php', '&lt;?php', $first);
-        $first = str_replace("\n", '</br>', $first);
-        $first = str_replace(' ', '&nbsp;', $first);
-        $first = str_replace('<em>', '<span class="code-comparison-highlight">', $first);
-        $first = str_replace('</em>', '</span>', $first);
+        $first      = trim($codeBlocks->item(0)->nodeValue);
+        $first      = str_replace('<?php', '&lt;?php', $first);
+        $first      = str_replace("\n", '</br>', $first);
+        $first      = str_replace(' ', '&nbsp;', $first);
+        $first      = str_replace('<em>', '<span class="code-comparison-highlight">', $first);
+        $first      = str_replace('</em>', '</span>', $first);
 
         $secondTitle = $codeBlocks->item(1)->getAttribute('title');
-        $second = trim($codeBlocks->item(1)->nodeValue);
-        $second = str_replace('<?php', '&lt;?php', $second);
-        $second = str_replace("\n", '</br>', $second);
-        $second = str_replace(' ', '&nbsp;', $second);
-        $second = str_replace('<em>', '<span class="code-comparison-highlight">', $second);
-        $second = str_replace('</em>', '</span>', $second);
+        $second      = trim($codeBlocks->item(1)->nodeValue);
+        $second      = str_replace('<?php', '&lt;?php', $second);
+        $second      = str_replace("\n", '</br>', $second);
+        $second      = str_replace(' ', '&nbsp;', $second);
+        $second      = str_replace('<em>', '<span class="code-comparison-highlight">', $second);
+        $second      = str_replace('</em>', '</span>', $second);
 
         echo '  <table class="code-comparison">'.PHP_EOL;
         echo '   <tr>'.PHP_EOL;
@@ -290,5 +290,3 @@ class PHP_CodeSniffer_DocGenerators_HTML extends PHP_CodeSniffer_DocGenerators_G
 
 
 }//end class
-
-?>
