@@ -3,7 +3,7 @@
  * Represents a PHP_CodeSniffer report.
  *
  * PHP version 5.
- * 
+ *
  * @category  PHP
  * @package   PHP_CodeSniffer
  * @author    Gabriele Santini <gsantini@sqli.com>
@@ -24,7 +24,7 @@
  * @copyright 2009-2014 SQLI <www.sqli.com>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 interface PHP_CodeSniffer_Report
@@ -38,14 +38,16 @@ interface PHP_CodeSniffer_Report
      * and FALSE if it ignored the file. Returning TRUE indicates that the file and
      * its data should be counted in the grand totals.
      *
-     * @param array   $report      Prepared report data.
-     * @param boolean $showSources Show sources?
-     * @param int     $width       Maximum allowed line width.
+     * @param array                $report      Prepared report data.
+     * @param PHP_CodeSniffer_File $phpcsFile   The file being reported on.
+     * @param boolean              $showSources Show sources?
+     * @param int                  $width       Maximum allowed line width.
      *
      * @return boolean
      */
     public function generateFileReport(
         $report,
+        PHP_CodeSniffer_File $phpcsFile,
         $showSources=false,
         $width=80
     );
@@ -53,12 +55,13 @@ interface PHP_CodeSniffer_Report
 
     /**
      * Generate the actual report.
-     * 
+     *
      * @param string  $cachedData    Any partial report data that was returned from
      *                               generateFileReport during the run.
      * @param int     $totalFiles    Total number of files processed during the run.
      * @param int     $totalErrors   Total number of errors found during the run.
      * @param int     $totalWarnings Total number of warnings found during the run.
+     * @param int     $totalFixable  Total number of problems that can be fixed.
      * @param boolean $showSources   Show sources?
      * @param int     $width         Maximum allowed line width.
      * @param boolean $toScreen      Is the report being printed to screen?
@@ -70,6 +73,7 @@ interface PHP_CodeSniffer_Report
         $totalFiles,
         $totalErrors,
         $totalWarnings,
+        $totalFixable,
         $showSources=false,
         $width=80,
         $toScreen=true
@@ -77,5 +81,3 @@ interface PHP_CodeSniffer_Report
 
 
 }//end interface
-
-?>
