@@ -26,7 +26,7 @@
  * @copyright 2009-2014 SQLI <www.sqli.com>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Reports_Full implements PHP_CodeSniffer_Report
@@ -40,14 +40,16 @@ class PHP_CodeSniffer_Reports_Full implements PHP_CodeSniffer_Report
      * and FALSE if it ignored the file. Returning TRUE indicates that the file and
      * its data should be counted in the grand totals.
      *
-     * @param array   $report      Prepared report data.
-     * @param boolean $showSources Show sources?
-     * @param int     $width       Maximum allowed line width.
+     * @param array                $report      Prepared report data.
+     * @param PHP_CodeSniffer_File $phpcsFile   The file being reported on.
+     * @param boolean              $showSources Show sources?
+     * @param int                  $width       Maximum allowed line width.
      *
      * @return boolean
      */
     public function generateFileReport(
         $report,
+        PHP_CodeSniffer_File $phpcsFile,
         $showSources=false,
         $width=80
     ) {
@@ -56,30 +58,6 @@ class PHP_CodeSniffer_Reports_Full implements PHP_CodeSniffer_Report
             return false;
         }
 
-        $width = max($width, 70);
-        $file  = $report['filename'];
-
-        echo PHP_EOL.'FILE: ';
-        if (strlen($file) <= ($width - 9)) {
-            echo $file;
-        } else {
-            echo '...'.substr($file, (strlen($file) - ($width - 9)));
-        }
-
-        echo PHP_EOL;
-        echo str_repeat('-', $width).PHP_EOL;
-
-        echo 'FOUND '.$report['errors'].' ERROR(S) ';
-        if ($report['warnings'] > 0) {
-            echo 'AND '.$report['warnings'].' WARNING(S) ';
-        }
-
-        echo 'AFFECTING '.count($report['messages']).' LINE(S)'.PHP_EOL;
-        echo str_repeat('-', $width).PHP_EOL;
-
-        // Work out the max line number for formatting.
-        $maxLineLength = max(array_map('strlen', array_keys($report['messages'])));
-
         // The length of the word ERROR or WARNING; used for padding.
         if ($report['warnings'] > 0) {
             $typeLength = 7;
@@ -87,45 +65,131 @@ class PHP_CodeSniffer_Reports_Full implements PHP_CodeSniffer_Report
             $typeLength = 5;
         }
 
+        // Work out the max line number length for formatting.
+        $maxLineNumLength = max(array_map('strlen', array_keys($report['messages'])));
+
         // The padding that all lines will require that are
         // printing an error message overflow.
-        $paddingLine2  = str_repeat(' ', ($maxLineLength + 1));
+        $paddingLine2  = str_repeat(' ', ($maxLineNumLength + 1));
         $paddingLine2 .= ' | ';
         $paddingLine2 .= str_repeat(' ', $typeLength);
         $paddingLine2 .= ' | ';
+        if ($report['fixable'] > 0) {
+            $paddingLine2 .= '    ';
+        }
+
+        $paddingLength = strlen($paddingLine2);
+
+        // Make sure the report width isn't too big.
+        $maxErrorLength = 0;
+        foreach ($report['messages'] as $line => $lineErrors) {
+            foreach ($lineErrors as $column => $colErrors) {
+                foreach ($colErrors as $error) {
+                    $length = strlen($error['message']);
+                    if ($showSources === true) {
+                        $length += (strlen($error['source']) + 3);
+                    }
+
+                    $maxErrorLength = max($maxErrorLength, ($length + 1));
+                }
+            }
+        }
+
+        $file       = $report['filename'];
+        $fileLength = strlen($file);
+        $maxWidth   = max(($fileLength + 6), ($maxErrorLength + $paddingLength));
+        $width      = min($width, $maxWidth);
+        if ($width < 70) {
+            $width = 70;
+        }
+
+        echo PHP_EOL."\033[1mFILE: ";
+        if ($fileLength <= ($width - 6)) {
+            echo $file;
+        } else {
+            echo '...'.substr($file, ($fileLength - ($width - 6)));
+        }
+
+        echo "\033[0m".PHP_EOL;
+        echo str_repeat('-', $width).PHP_EOL;
+
+        echo "\033[1m".'FOUND '.$report['errors'].' ERROR';
+        if ($report['errors'] !== 1) {
+            echo 'S';
+        }
+
+        if ($report['warnings'] > 0) {
+            echo ' AND '.$report['warnings'].' WARNING';
+            if ($report['warnings'] !== 1) {
+                echo 'S';
+            }
+        }
+
+        echo ' AFFECTING '.count($report['messages']).' LINE';
+        if (count($report['messages']) !== 1) {
+            echo 'S';
+        }
+
+        echo "\033[0m".PHP_EOL;
+        echo str_repeat('-', $width).PHP_EOL;
 
         // The maximum amount of space an error message can use.
-        $maxErrorSpace = ($width - strlen($paddingLine2) - 1);
+        $maxErrorSpace = ($width - $paddingLength - 1);
+        if ($showSources === true) {
+            // Account for the chars used to print colors.
+            $maxErrorSpace += 8;
+        }
 
         foreach ($report['messages'] as $line => $lineErrors) {
             foreach ($lineErrors as $column => $colErrors) {
                 foreach ($colErrors as $error) {
                     $message = $error['message'];
                     if ($showSources === true) {
-                        $message .= ' ('.$error['source'].')';
+                        $message = "\033[1m".$message."\033[0m".' ('.$error['source'].')';
                     }
 
                     // The padding that goes on the front of the line.
-                    $padding  = ($maxLineLength - strlen($line));
+                    $padding  = ($maxLineNumLength - strlen($line));
                     $errorMsg = wordwrap(
                         $message,
                         $maxErrorSpace,
                         PHP_EOL.$paddingLine2
                     );
 
-                    echo ' '.str_repeat(' ', $padding).$line.' | '.$error['type'];
+                    echo ' '.str_repeat(' ', $padding).$line.' | ';
                     if ($error['type'] === 'ERROR') {
+                        echo "\033[31mERROR\033[0m";
                         if ($report['warnings'] > 0) {
                             echo '  ';
                         }
+                    } else {
+                        echo "\033[33mWARNING\033[0m";
                     }
 
-                    echo ' | '.$errorMsg.PHP_EOL;
+                    echo ' | ';
+                    if ($report['fixable'] > 0) {
+                        echo '[';
+                        if ($error['fixable'] === true) {
+                            echo 'x';
+                        } else {
+                            echo ' ';
+                        }
+
+                        echo '] ';
+                    }
+
+                    echo $errorMsg.PHP_EOL;
                 }//end foreach
             }//end foreach
         }//end foreach
 
-        echo str_repeat('-', $width).PHP_EOL.PHP_EOL;
+        echo str_repeat('-', $width).PHP_EOL;
+        if ($report['fixable'] > 0) {
+            echo "\033[1m".'PHPCBF CAN FIX THE '.$report['fixable'].' MARKED SNIFF VIOLATIONS AUTOMATICALLY'."\033[0m".PHP_EOL;
+            echo str_repeat('-', $width).PHP_EOL;
+        }
+
+        echo PHP_EOL;
         return true;
 
     }//end generateFileReport()
@@ -139,6 +203,7 @@ class PHP_CodeSniffer_Reports_Full implements PHP_CodeSniffer_Report
      * @param int     $totalFiles    Total number of files processed during the run.
      * @param int     $totalErrors   Total number of errors found during the run.
      * @param int     $totalWarnings Total number of warnings found during the run.
+     * @param int     $totalFixable  Total number of problems that can be fixed.
      * @param boolean $showSources   Show sources?
      * @param int     $width         Maximum allowed line width.
      * @param boolean $toScreen      Is the report being printed to screen?
@@ -150,6 +215,7 @@ class PHP_CodeSniffer_Reports_Full implements PHP_CodeSniffer_Report
         $totalFiles,
         $totalErrors,
         $totalWarnings,
+        $totalFixable,
         $showSources=false,
         $width=80,
         $toScreen=true
@@ -160,16 +226,11 @@ class PHP_CodeSniffer_Reports_Full implements PHP_CodeSniffer_Report
 
         echo $cachedData;
 
-        if ($toScreen === true
-            && PHP_CODESNIFFER_INTERACTIVE === false
-            && class_exists('PHP_Timer', false) === true
-        ) {
-            echo PHP_Timer::resourceUsage().PHP_EOL.PHP_EOL;
+        if ($toScreen === true && PHP_CODESNIFFER_INTERACTIVE === false) {
+            PHP_CodeSniffer_Reporting::printRunTime();
         }
 
     }//end generate()
 
 
 }//end class
-
-?>
