@@ -26,7 +26,7 @@
  * @copyright 2009-2014 SQLI <www.sqli.com>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
@@ -47,14 +47,16 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
      * and FALSE if it ignored the file. Returning TRUE indicates that the file and
      * its data should be counted in the grand totals.
      *
-     * @param array   $report      Prepared report data.
-     * @param boolean $showSources Show sources?
-     * @param int     $width       Maximum allowed line width.
+     * @param array                $report      Prepared report data.
+     * @param PHP_CodeSniffer_File $phpcsFile   The file being reported on.
+     * @param boolean              $showSources Show sources?
+     * @param int                  $width       Maximum allowed line width.
      *
      * @return boolean
      */
     public function generateFileReport(
         $report,
+        PHP_CodeSniffer_File $phpcsFile,
         $showSources=false,
         $width=80
     ) {
@@ -68,13 +70,41 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
                 foreach ($colErrors as $error) {
                     $source = $error['source'];
                     if (isset($this->_sourceCache[$source]) === false) {
-                        $this->_sourceCache[$source] = 1;
+                        if ($showSources === true) {
+                            $parts = null;
+                            $sniff = $source;
+                        } else {
+                            $parts = explode('.', $source);
+                            if ($parts[0] === 'Internal') {
+                                $parts[2] = $parts[1];
+                                $parts[1] = '';
+                            }
+
+                            $parts[1] = $this->makeFriendlyName($parts[1]);
+
+                            $sniff = $this->makeFriendlyName($parts[2]);
+                            if (isset($parts[3]) === true) {
+                                $name    = $this->makeFriendlyName($parts[3]);
+                                $name[0] = strtolower($name[0]);
+                                $sniff  .= ' '.$name;
+                                unset($parts[3]);
+                            }
+
+                            $parts[2] = $sniff;
+                        }//end if
+
+                        $this->_sourceCache[$source] = array(
+                                                        'count'   => 1,
+                                                        'fixable' => $error['fixable'],
+                                                        'parts'   => $parts,
+                                                        'strlen'  => strlen($sniff),
+                                                       );
                     } else {
-                        $this->_sourceCache[$source]++;
-                    }
-                }
-            }
-        }
+                        $this->_sourceCache[$source]['count']++;
+                    }//end if
+                }//end foreach
+            }//end foreach
+        }//end foreach
 
         return true;
 
@@ -89,6 +119,7 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
      * @param int     $totalFiles    Total number of files processed during the run.
      * @param int     $totalErrors   Total number of errors found during the run.
      * @param int     $totalWarnings Total number of warnings found during the run.
+     * @param int     $totalFixable  Total number of problems that can be fixed.
      * @param boolean $showSources   Show sources?
      * @param int     $width         Maximum allowed line width.
      * @param boolean $toScreen      Is the report being printed to screen?
@@ -100,35 +131,79 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
         $totalFiles,
         $totalErrors,
         $totalWarnings,
+        $totalFixable,
         $showSources=false,
         $width=80,
         $toScreen=true
     ) {
-        $width = max($width, 70);
-
         if (empty($this->_sourceCache) === true) {
             // Nothing to show.
             return;
         }
 
+        // Make sure the report width isn't too big.
+        $maxLength = 0;
+        foreach ($this->_sourceCache as $source => $data) {
+            $maxLength = max($maxLength, $data['strlen']);
+        }
+
+        if ($showSources === true) {
+            $width = min($width, ($maxLength + 11));
+        } else {
+            $width = min($width, ($maxLength + 41));
+        }
+
+        $width = max($width, 70);
+
         asort($this->_sourceCache);
         $this->_sourceCache = array_reverse($this->_sourceCache);
 
-        echo PHP_EOL.'PHP CODE SNIFFER VIOLATION SOURCE SUMMARY'.PHP_EOL;
-        echo str_repeat('-', $width).PHP_EOL;
+        echo PHP_EOL."\033[1mPHP CODE SNIFFER VIOLATION SOURCE SUMMARY\033[0m".PHP_EOL;
+        echo str_repeat('-', $width).PHP_EOL."\033[1m";
         if ($showSources === true) {
-            echo 'SOURCE'.str_repeat(' ', ($width - 11)).'COUNT'.PHP_EOL;
-            echo str_repeat('-', $width).PHP_EOL;
+            if ($totalFixable > 0) {
+                echo '    SOURCE'.str_repeat(' ', ($width - 15)).'COUNT'.PHP_EOL;
+            } else {
+                echo 'SOURCE'.str_repeat(' ', ($width - 11)).'COUNT'.PHP_EOL;
+            }
         } else {
-            echo 'STANDARD  CATEGORY            SNIFF'.str_repeat(' ', ($width - 40)).'COUNT'.PHP_EOL;
-            echo str_repeat('-', $width).PHP_EOL;
+            if ($totalFixable > 0) {
+                echo '    STANDARD  CATEGORY            SNIFF'.str_repeat(' ', ($width - 44)).'COUNT'.PHP_EOL;
+            } else {
+                echo 'STANDARD  CATEGORY            SNIFF'.str_repeat(' ', ($width - 40)).'COUNT'.PHP_EOL;
+            }
         }
 
-        foreach ($this->_sourceCache as $source => $count) {
+        echo "\033[0m".str_repeat('-', $width).PHP_EOL;
+
+        $fixableSources = 0;
+        $maxSniffWidth  = 37;
+        if ($totalFixable > 0) {
+            $maxSniffWidth += 4;
+        }
+
+        foreach ($this->_sourceCache as $source => $sourceData) {
+            if ($totalFixable > 0) {
+                echo '[';
+                if ($sourceData['fixable'] === true) {
+                    echo 'x';
+                    $fixableSources++;
+                } else {
+                    echo ' ';
+                }
+
+                echo '] ';
+            }
+
             if ($showSources === true) {
-                echo $source.str_repeat(' ', ($width - 5 - strlen($source)));
+                echo $source;
+                if ($totalFixable > 0) {
+                    echo str_repeat(' ', ($width - 9 - strlen($source)));
+                } else {
+                    echo str_repeat(' ', ($width - 5 - strlen($source)));
+                }
             } else {
-                $parts = explode('.', $source);
+                $parts = $sourceData['parts'];
 
                 if (strlen($parts[0]) > 8) {
                     $parts[0] = substr($parts[0], 0, ((strlen($parts[0]) - 8) * -1));
@@ -136,40 +211,50 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
 
                 echo $parts[0].str_repeat(' ', (10 - strlen($parts[0])));
 
-                $category = $this->makeFriendlyName($parts[1]);
+                $category = $parts[1];
                 if (strlen($category) > 18) {
                     $category = substr($category, 0, ((strlen($category) - 18) * -1));
                 }
 
                 echo $category.str_repeat(' ', (20 - strlen($category)));
 
-                $sniff = $this->makeFriendlyName($parts[2]);
-                if (isset($parts[3]) === true) {
-                    $name    = $this->makeFriendlyName($parts[3]);
-                    $name[0] = strtolower($name[0]);
-                    $sniff  .= ' '.$name;
+                $sniff = $parts[2];
+                if (strlen($sniff) > ($width - $maxSniffWidth)) {
+                    $sniff = substr($sniff, 0, ($width - $maxSniffWidth - strlen($sniff)));
                 }
 
-                if (strlen($sniff) > ($width - 37)) {
-                    $sniff = substr($sniff, 0, ($width - 37 - strlen($sniff)));
+                if ($totalFixable > 0) {
+                    echo $sniff.str_repeat(' ', ($width - 39 - strlen($sniff)));
+                } else {
+                    echo $sniff.str_repeat(' ', ($width - 35 - strlen($sniff)));
                 }
-
-                echo $sniff.str_repeat(' ', ($width - 35 - strlen($sniff)));
             }//end if
 
-            echo $count.PHP_EOL;
+            echo $sourceData['count'].PHP_EOL;
         }//end foreach
 
         echo str_repeat('-', $width).PHP_EOL;
-        echo 'A TOTAL OF '.($totalErrors + $totalWarnings).' SNIFF VIOLATION(S) ';
-        echo 'WERE FOUND IN '.count($this->_sourceCache).' SOURCE(S)'.PHP_EOL;
-        echo str_repeat('-', $width).PHP_EOL.PHP_EOL;
+        echo "\033[1m".'A TOTAL OF '.($totalErrors + $totalWarnings).' SNIFF VIOLATION';
+        if (($totalErrors + $totalWarnings) > 1) {
+            echo 'S';
+        }
 
-        if ($toScreen === true
-            && PHP_CODESNIFFER_INTERACTIVE === false
-            && class_exists('PHP_Timer', false) === true
-        ) {
-            echo PHP_Timer::resourceUsage().PHP_EOL.PHP_EOL;
+        echo ' WERE FOUND IN '.count($this->_sourceCache).' SOURCE';
+        if (count($this->_sourceCache) !== 1) {
+            echo 'S';
+        }
+
+        echo "\033[0m";
+
+        if ($totalFixable > 0) {
+            echo PHP_EOL.str_repeat('-', $width).PHP_EOL;
+            echo "\033[1mPHPCBF CAN FIX THE $fixableSources MARKED SOURCES AUTOMATICALLY ($totalFixable VIOLATIONS IN TOTAL)\033[0m";
+        }
+
+        echo PHP_EOL.str_repeat('-', $width).PHP_EOL.PHP_EOL;
+
+        if ($toScreen === true && PHP_CODESNIFFER_INTERACTIVE === false) {
+            PHP_CodeSniffer_Reporting::printRunTime();
         }
 
     }//end generate()
@@ -184,6 +269,10 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
      */
     public function makeFriendlyName($name)
     {
+        if (trim($name) === '') {
+            return '';
+        }
+
         $friendlyName = '';
         $length       = strlen($name);
 
@@ -233,5 +322,3 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
 
 
 }//end class
-
-?>
