@@ -26,7 +26,7 @@
  * @copyright 2009-2014 SQLI <www.sqli.com>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Reports_Xml implements PHP_CodeSniffer_Report
@@ -40,14 +40,16 @@ class PHP_CodeSniffer_Reports_Xml implements PHP_CodeSniffer_Report
      * and FALSE if it ignored the file. Returning TRUE indicates that the file and
      * its data should be counted in the grand totals.
      *
-     * @param array   $report      Prepared report data.
-     * @param boolean $showSources Show sources?
-     * @param int     $width       Maximum allowed line width.
+     * @param array                $report      Prepared report data.
+     * @param PHP_CodeSniffer_File $phpcsFile   The file being reported on.
+     * @param boolean              $showSources Show sources?
+     * @param int                  $width       Maximum allowed line width.
      *
      * @return boolean
      */
     public function generateFileReport(
         $report,
+        PHP_CodeSniffer_File $phpcsFile,
         $showSources=false,
         $width=80
     ) {
@@ -64,6 +66,7 @@ class PHP_CodeSniffer_Reports_Xml implements PHP_CodeSniffer_Report
         $out->writeAttribute('name', $report['filename']);
         $out->writeAttribute('errors', $report['errors']);
         $out->writeAttribute('warnings', $report['warnings']);
+        $out->writeAttribute('fixable', $report['fixable']);
 
         foreach ($report['messages'] as $line => $lineErrors) {
             foreach ($lineErrors as $column => $colErrors) {
@@ -78,6 +81,7 @@ class PHP_CodeSniffer_Reports_Xml implements PHP_CodeSniffer_Report
                     $out->writeAttribute('column', $column);
                     $out->writeAttribute('source', $error['source']);
                     $out->writeAttribute('severity', $error['severity']);
+                    $out->writeAttribute('fixable', (int) $error['fixable']);
                     $out->text($error['message']);
                     $out->endElement();
                 }
@@ -100,6 +104,7 @@ class PHP_CodeSniffer_Reports_Xml implements PHP_CodeSniffer_Report
      * @param int     $totalFiles    Total number of files processed during the run.
      * @param int     $totalErrors   Total number of errors found during the run.
      * @param int     $totalWarnings Total number of warnings found during the run.
+     * @param int     $totalFixable  Total number of problems that can be fixed.
      * @param boolean $showSources   Show sources?
      * @param int     $width         Maximum allowed line width.
      * @param boolean $toScreen      Is the report being printed to screen?
@@ -111,6 +116,7 @@ class PHP_CodeSniffer_Reports_Xml implements PHP_CodeSniffer_Report
         $totalFiles,
         $totalErrors,
         $totalWarnings,
+        $totalFixable,
         $showSources=false,
         $width=80,
         $toScreen=true
@@ -124,5 +130,3 @@ class PHP_CodeSniffer_Reports_Xml implements PHP_CodeSniffer_Report
 
 
 }//end class
-
-?>
