@@ -29,7 +29,7 @@ if (class_exists('PHP_CodeSniffer_Standards_IncorrectPatternException', true) ==
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_CodeSniffer_Sniff
@@ -97,7 +97,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * <i>getPatterns()</i> method to register the patterns they wish to test.
      *
      * @return int[]
-     * @see process()
+     * @see    process()
      */
     public final function register()
     {
@@ -124,7 +124,6 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
             }
 
             $this->_parsedPatterns[$tokenType][] = $patternArray;
-
         }//end foreach
 
         return array_unique(array_merge($listenTypes, $this->_supplementaryTokens));
@@ -170,7 +169,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      *
      * @param array $pattern The pattern to acquire the listener for.
      *
-     * @return int The postition in the pattern that this test should register
+     * @return int The position in the pattern that this test should register
      *             as the listener.
      * @throws PHP_CodeSniffer_Exception If we could not determine a token
      *                                         to listen for.
@@ -196,13 +195,13 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * Processes the test.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The PHP_CodeSniffer file where the
-     *                                        token occured.
-     * @param int                  $stackPtr  The postion in the tokens stack
+     *                                        token occurred.
+     * @param int                  $stackPtr  The position in the tokens stack
      *                                        where the listening token type was
      *                                        found.
      *
      * @return void
-     * @see register()
+     * @see    register()
      */
     public final function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
@@ -266,8 +265,8 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      *                                          parsed token representation of the
      *                                          pattern.
      * @param PHP_CodeSniffer_File $phpcsFile   The PHP_CodeSniffer file where the
-     *                                          token occured.
-     * @param int                  $stackPtr    The postion in the tokens stack where
+     *                                          token occurred.
+     * @param int                  $stackPtr    The position in the tokens stack where
      *                                          the listening token type was found.
      *
      * @return array
@@ -380,7 +379,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                     $found = 'abc';
                 } else if ($pattern[$i]['type'] === 'newline') {
                     if ($this->ignoreComments === true
-                        && in_array($tokens[$stackPtr]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true
+                        && isset(PHP_CodeSniffer_Tokens::$commentTokens[$tokens[$stackPtr]['code']]) === true
                     ) {
                         $startComment = $phpcsFile->findPrevious(
                             PHP_CodeSniffer_Tokens::$commentTokens,
@@ -410,7 +409,8 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                             // so check the token before to make sure. If it is a newline, we
                             // can ignore the error here.
                             if (($tokens[($stackPtr - 1)]['content'] !== $phpcsFile->eolChar)
-                                && ($this->ignoreComments === true && in_array($tokens[($stackPtr - 1)]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === false)
+                                && ($this->ignoreComments === true
+                                && isset(PHP_CodeSniffer_Tokens::$commentTokens[$tokens[($stackPtr - 1)]['code']]) === false)
                             ) {
                                 $hasError = true;
                             } else {
@@ -422,7 +422,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                     } else {
                         $found    = $tokens[$stackPtr]['content'].$found;
                         $hasError = true;
-                    }
+                    }//end if
 
                     if ($hasError === false && $pattern[($i - 1)]['type'] !== 'newline') {
                         // Make sure they only have 1 newline.
@@ -440,19 +440,25 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         $patternLen        = count($pattern);
 
         for ($i = $patternInfo['listen_pos']; $i < $patternLen; $i++) {
+            if (isset($tokens[$stackPtr]) === false) {
+                break;
+            }
+
             if ($pattern[$i]['type'] === 'token') {
                 if ($pattern[$i]['token'] === T_WHITESPACE) {
                     if ($this->ignoreComments === true) {
                         // If we are ignoring comments, check to see if this current
                         // token is a comment. If so skip it.
-                        if (in_array($tokens[$stackPtr]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true) {
+                        if (isset(PHP_CodeSniffer_Tokens::$commentTokens[$tokens[$stackPtr]['code']]) === true) {
                             continue;
                         }
 
                         // If the next token is a comment, the we need to skip the
                         // current token as we should allow a space before a
                         // comment for readability.
-                        if (in_array($tokens[($stackPtr + 1)]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true) {
+                        if (isset($tokens[($stackPtr + 1)]) === true
+                            && isset(PHP_CodeSniffer_Tokens::$commentTokens[$tokens[($stackPtr + 1)]['code']]) === true
+                        ) {
                             continue;
                         }
                     }
@@ -479,7 +485,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
 
                             $lastAddedStackPtr = $stackPtr;
                             $stackPtr          = $next;
-                        }
+                        }//end if
 
                         if ($stackPtr !== $lastAddedStackPtr) {
                             $found .= $tokenContent;
@@ -553,7 +559,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                         $hasComment = false;
                         for ($j = $stackPtr; $j < $next; $j++) {
                             $found .= $tokens[$j]['content'];
-                            if (in_array($tokens[$j]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true) {
+                            if (isset(PHP_CodeSniffer_Tokens::$commentTokens[$tokens[$j]['code']]) === true) {
                                 $hasComment = true;
                             }
                         }
@@ -598,7 +604,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                     );
 
                     if ($next === false) {
-                        // Couldn't find the next token, sowe we must
+                        // Couldn't find the next token, so we must
                         // be using the wrong pattern.
                         return false;
                     }
@@ -658,7 +664,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 } else {
                     if ($this->ignoreComments === false) {
                         // The newline character cannot be part of a comment.
-                        if (in_array($tokens[$newline]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true) {
+                        if (isset(PHP_CodeSniffer_Tokens::$commentTokens[$tokens[$newline]['code']]) === true) {
                             $hasError = true;
                         }
                     }
@@ -744,11 +750,11 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * Registers any supplementary tokens that this test might wish to process.
      *
      * A sniff may wish to register supplementary tests when it wishes to group
-     * an arbitary validation that cannot be performed using a pattern, with
+     * an arbitrary validation that cannot be performed using a pattern, with
      * other pattern tests.
      *
      * @return int[]
-     * @see processSupplementary()
+     * @see    processSupplementary()
      */
     protected function registerSupplementary()
     {
@@ -766,7 +772,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
       *                                        process.
       *
       * @return void
-      * @see registerSupplementary()
+      * @see    registerSupplementary()
       */
     protected function processSupplementary(
         PHP_CodeSniffer_File $phpcsFile,
@@ -782,8 +788,8 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * @param string $pattern The pattern to parse.
      *
      * @return array The parsed pattern array.
-     * @see _createSkipPattern()
-     * @see _createTokenPattern()
+     * @see    _createSkipPattern()
+     * @see    _createTokenPattern()
      */
     private function _parse($pattern)
     {
@@ -793,7 +799,6 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         $firstToken = 0;
 
         for ($i = 0; $i < $length; $i++) {
-
             $specialPattern = false;
             $isLastChar     = ($i === ($length - 1));
             $oldFirstToken  = $firstToken;
@@ -805,7 +810,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 $specialPattern = $this->_createSkipPattern($pattern, ($i - 1));
                 $lastToken      = ($i - $firstToken);
                 $firstToken     = ($i + 3);
-                $i              = ($i + 2);
+                $i = ($i + 2);
 
                 if ($specialPattern['to'] !== 'unknown') {
                     $firstToken++;
@@ -814,13 +819,13 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 $specialPattern = array('type' => 'string');
                 $lastToken      = ($i - $firstToken);
                 $firstToken     = ($i + 3);
-                $i              = ($i + 2);
+                $i = ($i + 2);
             } else if (substr($pattern, $i, 3) === 'EOL') {
                 $specialPattern = array('type' => 'newline');
                 $lastToken      = ($i - $firstToken);
                 $firstToken     = ($i + 3);
-                $i              = ($i + 2);
-            }
+                $i = ($i + 2);
+            }//end if
 
             if ($specialPattern !== false || $isLastChar === true) {
                 // If we are at the end of the string, don't worry about a limit.
@@ -874,8 +879,8 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * @param string $from    The token content that the skip pattern starts from.
      *
      * @return array The pattern step.
-     * @see _createTokenPattern()
-     * @see _parse()
+     * @see    _createTokenPattern()
+     * @see    _parse()
      */
     private function _createSkipPattern($pattern, $from)
     {
@@ -905,12 +910,12 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
             case ')':
                 $nestedParenthesis++;
                 break;
-            }
+            }//end switch
 
             if (isset($skip['to']) === true) {
                 break;
             }
-        }
+        }//end for
 
         if (isset($skip['to']) === false) {
             $skip['to'] = 'unknown';
@@ -927,22 +932,19 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * @param string $str The tokens string that the pattern should match.
      *
      * @return array The pattern step.
-     * @see _createSkipPattern()
-     * @see _parse()
+     * @see    _createSkipPattern()
+     * @see    _parse()
      */
     private function _createTokenPattern($str)
     {
         // Don't add a space after the closing php tag as it will add a new
         // whitespace token.
-        $tokens = token_get_all('<?php '.$str.'?>');
+        $tokenizer = new PHP_CodeSniffer_Tokenizers_PHP();
+        $tokens    = $tokenizer->tokenizeString('<?php '.$str.'?>');
 
         // Remove the <?php tag from the front and the end php tag from the back.
         $tokens = array_slice($tokens, 1, (count($tokens) - 2));
 
-        foreach ($tokens as &$token) {
-            $token = PHP_CodeSniffer::standardiseToken($token);
-        }
-
         $patterns = array();
         foreach ($tokens as $patternInfo) {
             $patterns[] = array(
@@ -958,5 +960,3 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
 
 
 }//end class
-
-?>
