@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Debug_ClosureLinterSniff implements PHP_CodeSniffer_Sniff
@@ -90,8 +90,6 @@ class Generic_Sniffs_Debug_ClosureLinterSniff implements PHP_CodeSniffer_Sniff
             return;
         }
 
-        $tokens = $phpcsFile->getTokens();
-
         foreach ($output as $finding) {
             $matches    = array();
             $numMatches = preg_match('/^(.*):([0-9]+):\(.*?([0-9]+)\)(.*)$/', $finding, $matches);
@@ -108,32 +106,22 @@ class Generic_Sniffs_Debug_ClosureLinterSniff implements PHP_CodeSniffer_Sniff
             $line  = (int) $matches[2];
             $error = trim($matches[4]);
 
-            // Find the token at the start of the line.
-            $lineToken = null;
-            foreach ($tokens as $ptr => $info) {
-                if ($info['line'] === $line) {
-                    $lineToken = $ptr;
-                    break;
-                }
-            }
-
-            if ($lineToken !== null) {
-                $message = 'gjslint says: (%s) %s';
-                $data    = array(
-                            $code,
-                            $error,
-                           );
-                if (in_array($code, $this->errorCodes) === true) {
-                    $phpcsFile->addError($message, $lineToken, 'ExternalToolError', $data);
-                } else {
-                    $phpcsFile->addWarning($message, $lineToken, 'ExternalTool', $data);
-                }
+            $message = 'gjslint says: (%s) %s';
+            $data    = array(
+                        $code,
+                        $error,
+                       );
+            if (in_array($code, $this->errorCodes) === true) {
+                $phpcsFile->addErrorOnLine($message, $line, 'ExternalToolError', $data);
+            } else {
+                $phpcsFile->addWarningOnLine($message, $line, 'ExternalTool', $data);
             }
         }//end foreach
 
+        // Ignore the rest of the file.
+        return ($phpcsFile->numTokens + 1);
+
     }//end process()
 
 
 }//end class
-
-?>
