@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Files_LineEndingsSniff implements PHP_CodeSniffer_Sniff
@@ -68,48 +68,77 @@ class Generic_Sniffs_Files_LineEndingsSniff implements PHP_CodeSniffer_Sniff
      * @param int                  $stackPtr  The position of the current token in
      *                                        the stack passed in $tokens.
      *
-     * @return void
+     * @return int
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
-        // We are only interested if this is the first open tag.
-        if ($stackPtr !== 0) {
-            if ($phpcsFile->findPrevious(T_OPEN_TAG, ($stackPtr - 1)) !== false) {
-                return;
-            }
-        }
-
         $found = $phpcsFile->eolChar;
         $found = str_replace("\n", '\n', $found);
         $found = str_replace("\r", '\r', $found);
 
-        if ($found !== $this->eolChar) {
-            // Check for single line files without an EOL. This is a very special
-            // case and the EOL char is set to \n when this happens.
-            if ($found === '\n') {
-                $tokens    = $phpcsFile->getTokens();
-                $lastToken = ($phpcsFile->numTokens - 1);
-                if ($tokens[$lastToken]['line'] === 1
-                    && $tokens[$lastToken]['content'] !== "\n"
-                ) {
-                    return;
-                }
+        $phpcsFile->recordMetric($stackPtr, 'EOL char', $found);
+
+        if ($found === $this->eolChar) {
+            // Ignore the rest of the file.
+            return ($phpcsFile->numTokens + 1);
+        }
+
+        // Check for single line files without an EOL. This is a very special
+        // case and the EOL char is set to \n when this happens.
+        if ($found === '\n') {
+            $tokens    = $phpcsFile->getTokens();
+            $lastToken = ($phpcsFile->numTokens - 1);
+            if ($tokens[$lastToken]['line'] === 1
+                && $tokens[$lastToken]['content'] !== "\n"
+            ) {
+                return;
+            }
+        }
+
+        $error    = 'End of line character is invalid; expected "%s" but found "%s"';
+        $expected = $this->eolChar;
+        $expected = str_replace("\n", '\n', $expected);
+        $expected = str_replace("\r", '\r', $expected);
+        $data     = array(
+                     $expected,
+                     $found,
+                    );
+
+        $fix = $phpcsFile->addFixableError($error, $stackPtr, 'InvalidEOLChar', $data);
+
+        if ($fix === true) {
+            $tokens = $phpcsFile->getTokens();
+            switch ($this->eolChar) {
+            case '\n':
+                $eolChar = "\n";
+                break;
+            case '\r':
+                $eolChar = "\r";
+                break;
+            case '\r\n':
+                $eolChar = "\r\n";
+                break;
+            default:
+                $eolChar = $this->eolChar;
+                break;
             }
 
-            $error    = 'End of line character is invalid; expected "%s" but found "%s"';
-            $expected = $this->eolChar;
-            $expected = str_replace("\n", '\n', $expected);
-            $expected = str_replace("\r", '\r', $expected);
-            $data     = array(
-                         $expected,
-                         $found,
-                        );
-            $phpcsFile->addError($error, $stackPtr, 'InvalidEOLChar', $data);
-        }
+            for ($i = $stackPtr; $i < $phpcsFile->numTokens; $i++) {
+                if (isset($tokens[($i + 1)]) === false
+                    || $tokens[($i + 1)]['line'] > $tokens[$i]['line']
+                ) {
+                    // Token is the last on a line.
+                    $newContent  = rtrim($tokens[$i]['content'], "\r\n");
+                    $newContent .= $eolChar;
+                    $phpcsFile->fixer->replaceToken($i, $newContent);
+                }
+            }
+        }//end if
+
+        // Ignore the rest of the file.
+        return ($phpcsFile->numTokens + 1);
 
     }//end process()
 
 
 }//end class
-
-?>
