@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Formatting_DisallowMultipleStatementsSniff implements PHP_CodeSniffer_Sniff
@@ -54,8 +54,9 @@ class Generic_Sniffs_Formatting_DisallowMultipleStatementsSniff implements PHP_C
     {
         $tokens = $phpcsFile->getTokens();
 
-        $prev = $phpcsFile->findPrevious(T_SEMICOLON, ($stackPtr - 1));
-        if ($prev === false) {
+        $prev = $phpcsFile->findPrevious(array(T_SEMICOLON, T_OPEN_TAG), ($stackPtr - 1));
+        if ($prev === false || $tokens[$prev]['code'] === T_OPEN_TAG) {
+            $phpcsFile->recordMetric($stackPtr, 'Multiple statements on same line', 'no');
             return;
         }
 
@@ -75,14 +76,24 @@ class Generic_Sniffs_Formatting_DisallowMultipleStatementsSniff implements PHP_C
         }
 
         if ($tokens[$prev]['line'] === $tokens[$stackPtr]['line']) {
+            $phpcsFile->recordMetric($stackPtr, 'Multiple statements on same line', 'yes');
+
             $error = 'Each PHP statement must be on a line by itself';
-            $phpcsFile->addError($error, $stackPtr, 'SameLine');
-            return;
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SameLine');
+            if ($fix === true) {
+                $phpcsFile->fixer->beginChangeset();
+                $phpcsFile->fixer->addNewline($prev);
+                if ($tokens[($prev + 1)]['code'] === T_WHITESPACE) {
+                    $phpcsFile->fixer->replaceToken(($prev + 1), '');
+                }
+
+                $phpcsFile->fixer->endChangeset();
+            }
+        } else {
+            $phpcsFile->recordMetric($stackPtr, 'Multiple statements on same line', 'no');
         }
 
     }//end process()
 
 
 }//end class
-
-?>
