@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Formatting_NoSpaceAfterCastSniff implements PHP_CodeSniffer_Sniff
@@ -56,14 +56,17 @@ class Generic_Sniffs_Formatting_NoSpaceAfterCastSniff implements PHP_CodeSniffer
     {
         $tokens = $phpcsFile->getTokens();
 
-        if ($tokens[($stackPtr + 1)]['code'] === T_WHITESPACE) {
-            $error = 'A cast statement must not be followed by a space';
-            $phpcsFile->addError($error, $stackPtr, 'SpaceFound');
+        if ($tokens[($stackPtr + 1)]['code'] !== T_WHITESPACE) {
+            return;
+        }
+
+        $error = 'A cast statement must not be followed by a space';
+        $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceFound');
+        if ($fix === true) {
+            $phpcsFile->fixer->replaceToken(($stackPtr + 1), '');
         }
 
     }//end process()
 
 
 }//end class
-
-?>
