@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Formatting_SpaceAfterCastSniff implements PHP_CodeSniffer_Sniff
@@ -58,18 +58,26 @@ class Generic_Sniffs_Formatting_SpaceAfterCastSniff implements PHP_CodeSniffer_S
 
         if ($tokens[($stackPtr + 1)]['code'] !== T_WHITESPACE) {
             $error = 'A cast statement must be followed by a single space';
-            $phpcsFile->addError($error, $stackPtr, 'NoSpace');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'NoSpace');
+            if ($fix === true) {
+                $phpcsFile->fixer->addContent($stackPtr, ' ');
+            }
+
+            $phpcsFile->recordMetric($stackPtr, 'Spacing after cast statement', 0);
             return;
         }
 
-        if ($tokens[($stackPtr + 1)]['content'] !== ' ') {
+        $phpcsFile->recordMetric($stackPtr, 'Spacing after cast statement', $tokens[($stackPtr + 1)]['length']);
+
+        if ($tokens[($stackPtr + 1)]['length'] !== 1) {
             $error = 'A cast statement must be followed by a single space';
-            $phpcsFile->addError($error, $stackPtr, 'TooMuchSpace');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'TooMuchSpace');
+            if ($fix === true) {
+                $phpcsFile->fixer->replaceToken(($stackPtr + 1), ' ');
+            }
         }
 
     }//end process()
 
 
 }//end class
-
-?>
