@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Functions_FunctionCallArgumentSpacingSniff implements PHP_CodeSniffer_Sniff
@@ -76,6 +76,10 @@ class Generic_Sniffs_Functions_FunctionCallArgumentSpacingSniff implements PHP_C
             return;
         }
 
+        if (isset($tokens[$openBracket]['parenthesis_closer']) === false) {
+            return;
+        }
+
         $closeBracket  = $tokens[$openBracket]['parenthesis_closer'];
         $nextSeparator = $openBracket;
 
@@ -107,27 +111,36 @@ class Generic_Sniffs_Functions_FunctionCallArgumentSpacingSniff implements PHP_C
 
             if ($tokens[$nextSeparator]['code'] === T_COMMA) {
                 if ($tokens[($nextSeparator - 1)]['code'] === T_WHITESPACE) {
-                    if (in_array($tokens[($nextSeparator - 2)]['code'], PHP_CodeSniffer_Tokens::$heredocTokens) === false) {
+                    if (isset(PHP_CodeSniffer_Tokens::$heredocTokens[$tokens[($nextSeparator - 2)]['code']]) === false) {
                         $error = 'Space found before comma in function call';
-                        $phpcsFile->addError($error, $nextSeparator, 'SpaceBeforeComma');
+                        $fix   = $phpcsFile->addFixableError($error, $nextSeparator, 'SpaceBeforeComma');
+                        if ($fix === true) {
+                            $phpcsFile->fixer->replaceToken(($nextSeparator - 1), '');
+                        }
                     }
                 }
 
                 if ($tokens[($nextSeparator + 1)]['code'] !== T_WHITESPACE) {
                     $error = 'No space found after comma in function call';
-                    $phpcsFile->addError($error, $nextSeparator, 'NoSpaceAfterComma');
+                    $fix   = $phpcsFile->addFixableError($error, $nextSeparator, 'NoSpaceAfterComma');
+                    if ($fix === true) {
+                        $phpcsFile->fixer->addContent($nextSeparator, ' ');
+                    }
                 } else {
-                    // If there is a newline in the space, then the must be formatting
+                    // If there is a newline in the space, then they must be formatting
                     // each argument on a newline, which is valid, so ignore it.
                     if (strpos($tokens[($nextSeparator + 1)]['content'], $phpcsFile->eolChar) === false) {
                         $space = strlen($tokens[($nextSeparator + 1)]['content']);
                         if ($space > 1) {
                             $error = 'Expected 1 space after comma in function call; %s found';
                             $data  = array($space);
-                            $phpcsFile->addError($error, $nextSeparator, 'TooMuchSpaceAfterComma', $data);
+                            $fix   = $phpcsFile->addFixableError($error, $nextSeparator, 'TooMuchSpaceAfterComma', $data);
+                            if ($fix === true) {
+                                $phpcsFile->fixer->replaceToken(($nextSeparator + 1), ' ');
+                            }
                         }
                     }
-                }
+                }//end if
             } else {
                 // Token is a variable.
                 $nextToken = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, ($nextSeparator + 1), $closeBracket, true);
@@ -135,12 +148,18 @@ class Generic_Sniffs_Functions_FunctionCallArgumentSpacingSniff implements PHP_C
                     if ($tokens[$nextToken]['code'] === T_EQUAL) {
                         if (($tokens[($nextToken - 1)]['code']) !== T_WHITESPACE) {
                             $error = 'Expected 1 space before = sign of default value';
-                            $phpcsFile->addError($error, $nextToken, 'NoSpaceBeforeEquals');
+                            $fix   = $phpcsFile->addFixableError($error, $nextToken, 'NoSpaceBeforeEquals');
+                            if ($fix === true) {
+                                $phpcsFile->fixer->addContentBefore($nextToken, ' ');
+                            }
                         }
 
                         if ($tokens[($nextToken + 1)]['code'] !== T_WHITESPACE) {
                             $error = 'Expected 1 space after = sign of default value';
-                            $phpcsFile->addError($error, $nextToken, 'NoSpaceAfterEquals');
+                            $fix   = $phpcsFile->addFixableError($error, $nextToken, 'NoSpaceAfterEquals');
+                            if ($fix === true) {
+                                $phpcsFile->fixer->addContent($nextToken, ' ');
+                            }
                         }
                     }
                 }
