@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_Functions_OpeningFunctionBraceKernighanRitchieUnitTest extends AbstractSniffUnitTest
@@ -56,6 +56,10 @@ class Generic_Tests_Functions_OpeningFunctionBraceKernighanRitchieUnitTest exten
                 82  => 1,
                 87  => 1,
                 104 => 1,
+                119 => 1,
+                123 => 1,
+                127 => 1,
+                132 => 1,
                );
 
     }//end getErrorList()
@@ -77,5 +81,3 @@ class Generic_Tests_Functions_OpeningFunctionBraceKernighanRitchieUnitTest exten
 
 
 }//end class
-
-?>
