@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_PHP_DisallowShortOpenTagUnitTest extends AbstractSniffUnitTest
@@ -43,7 +43,7 @@ class Generic_Tests_PHP_DisallowShortOpenTagUnitTest extends AbstractSniffUnitTe
     public function getErrorList()
     {
         $option = (boolean) ini_get('short_open_tag');
-        if ($option === true) {
+        if ($option === true || defined('HHVM_VERSION') === true) {
             return array(
                     4 => 1,
                     5 => 1,
