@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class MySource_Sniffs_CSS_BrowserSpecificStylesSniff implements PHP_CodeSniffer_Sniff
@@ -45,11 +45,11 @@ class MySource_Sniffs_CSS_BrowserSpecificStylesSniff implements PHP_CodeSniffer_
      * @var array
      */
     protected $specificStylesheets = array(
-                                      'moz',
-                                      'ie',
-                                      'ie7',
-                                      'ie8',
-                                      'webkit',
+                                      'moz'    => true,
+                                      'ie'     => true,
+                                      'ie7'    => true,
+                                      'ie8'    => true,
+                                      'webkit' => true,
                                      );
 
 
@@ -81,7 +81,7 @@ class MySource_Sniffs_CSS_BrowserSpecificStylesSniff implements PHP_CodeSniffer_
         $breakChar = strrpos($filename, '_');
         if ($breakChar !== false && substr($filename, -4) === '.css') {
             $specific = substr($filename, ($breakChar + 1), -4);
-            if (in_array($specific, $this->specificStylesheets) === true) {
+            if (isset($this->specificStylesheets[$specific]) === true) {
                 return;
             }
         }
@@ -98,5 +98,3 @@ class MySource_Sniffs_CSS_BrowserSpecificStylesSniff implements PHP_CodeSniffer_
 
 
 }//end class
-
-?>
