@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PEAR_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Sniff
@@ -57,14 +57,27 @@ class PEAR_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Sniff
         $tokens = $phpcsFile->getTokens();
 
         if ($tokens[$stackPtr]['content']{0} === '#') {
+            $phpcsFile->recordMetric($stackPtr, 'Inline comment style', '# ...');
+
             $error  = 'Perl-style comments are not allowed. Use "// Comment."';
             $error .= ' or "/* comment */" instead.';
-            $phpcsFile->addError($error, $stackPtr, 'WrongStyle');
+            $fix    = $phpcsFile->addFixableError($error, $stackPtr, 'WrongStyle');
+            if ($fix === true) {
+                $newComment = ltrim($tokens[$stackPtr]['content'], '# ');
+                $newComment = '// '.$newComment;
+                $phpcsFile->fixer->replaceToken($stackPtr, $newComment);
+            }
+        } else if ($tokens[$stackPtr]['content']{0} === '/'
+            && $tokens[$stackPtr]['content']{1} === '/'
+        ) {
+            $phpcsFile->recordMetric($stackPtr, 'Inline comment style', '// ...');
+        } else if ($tokens[$stackPtr]['content']{0} === '/'
+            && $tokens[$stackPtr]['content']{1} === '*'
+        ) {
+            $phpcsFile->recordMetric($stackPtr, 'Inline comment style', '/* ... */');
         }
 
     }//end process()
 
 
 }//end class
-
-?>
