@@ -22,12 +22,22 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
+
     /**
      * The number of spaces code should be indented.
      *
@@ -64,7 +74,7 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
      */
     public function register()
     {
-        return array(T_STRING);
+        return PHP_CodeSniffer_Tokens::$functionNameTokens;
 
     }//end register()
 
@@ -111,14 +121,30 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
         if (($stackPtr + 1) !== $openBracket) {
             // Checking this: $value = my_function[*](...).
             $error = 'Space before opening parenthesis of function call prohibited';
-            $phpcsFile->addError($error, $stackPtr, 'SpaceBeforeOpenBracket');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceBeforeOpenBracket');
+            if ($fix === true) {
+                $phpcsFile->fixer->beginChangeset();
+                for ($i = ($stackPtr + 1); $i < $openBracket; $i++) {
+                    $phpcsFile->fixer->replaceToken($i, '');
+                }
+
+                $phpcsFile->fixer->endChangeset();
+            }
         }
 
         $next = $phpcsFile->findNext(T_WHITESPACE, ($closeBracket + 1), null, true);
         if ($tokens[$next]['code'] === T_SEMICOLON) {
-            if (in_array($tokens[($closeBracket + 1)]['code'], PHP_CodeSniffer_Tokens::$emptyTokens) === true) {
+            if (isset(PHP_CodeSniffer_Tokens::$emptyTokens[$tokens[($closeBracket + 1)]['code']]) === true) {
                 $error = 'Space after closing parenthesis of function call prohibited';
-                $phpcsFile->addError($error, $closeBracket, 'SpaceAfterCloseBracket');
+                $fix   = $phpcsFile->addFixableError($error, $closeBracket, 'SpaceAfterCloseBracket');
+                if ($fix === true) {
+                    $phpcsFile->fixer->beginChangeset();
+                    for ($i = ($closeBracket + 1); $i < $next; $i++) {
+                        $phpcsFile->fixer->replaceToken($i, '');
+                    }
+
+                    $phpcsFile->fixer->endChangeset();
+                }
             }
         }
 
@@ -172,7 +198,6 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
      */
     public function processSingleLineCall(PHP_CodeSniffer_File $phpcsFile, $stackPtr, $openBracket, $tokens)
     {
-
         $closer = $tokens[$openBracket]['parenthesis_closer'];
         if ($openBracket === ($closer - 1)) {
             return;
@@ -181,7 +206,10 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
         if ($this->requiredSpacesAfterOpen === 0 && $tokens[($openBracket + 1)]['code'] === T_WHITESPACE) {
             // Checking this: $value = my_function([*]...).
             $error = 'Space after opening parenthesis of function call prohibited';
-            $phpcsFile->addError($error, $stackPtr, 'SpaceAfterOpenBracket');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceAfterOpenBracket');
+            if ($fix === true) {
+                $phpcsFile->fixer->replaceToken(($openBracket + 1), '');
+            }
         } else if ($this->requiredSpacesAfterOpen > 0) {
             $spaceAfterOpen = 0;
             if ($tokens[($openBracket + 1)]['code'] === T_WHITESPACE) {
@@ -194,13 +222,29 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
                           $this->requiredSpacesAfterOpen,
                           $spaceAfterOpen,
                          );
-                $phpcsFile->addError($error, $stackPtr, 'SpaceAfterOpenBracket', $data);
+                $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceAfterOpenBracket', $data);
+                if ($fix === true) {
+                    $padding = str_repeat(' ', $this->requiredSpacesAfterOpen);
+                    if ($spaceAfterOpen === 0) {
+                        $phpcsFile->fixer->addContent($openBracket, $padding);
+                    } else {
+                        $phpcsFile->fixer->replaceToken(($openBracket + 1), $padding);
+                    }
+                }
             }
-        }
+        }//end if
 
         // Checking this: $value = my_function(...[*]).
         $spaceBeforeClose = 0;
-        if ($tokens[($closer - 1)]['code'] === T_WHITESPACE) {
+        $prev = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($closer - 1), $openBracket, true);
+        if ($tokens[$prev]['code'] === T_END_HEREDOC || $tokens[$prev]['code'] === T_END_NOWDOC) {
+            // Need a newline after these tokens, so ignore this rule.
+            return;
+        }
+
+        if ($tokens[$prev]['line'] !== $tokens[$closer]['line']) {
+            $spaceBeforeClose = 'newline';
+        } else if ($tokens[($closer - 1)]['code'] === T_WHITESPACE) {
             $spaceBeforeClose = strlen($tokens[($closer - 1)]['content']);
         }
 
@@ -210,7 +254,15 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
                       $this->requiredSpacesBeforeClose,
                       $spaceBeforeClose,
                      );
-            $phpcsFile->addError($error, $stackPtr, 'SpaceBeforeCloseBracket', $data);
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceBeforeCloseBracket', $data);
+            if ($fix === true) {
+                $padding = str_repeat(' ', $this->requiredSpacesBeforeClose);
+                if ($spaceBeforeClose === 0) {
+                    $phpcsFile->fixer->addContentBefore($closer, $padding);
+                } else {
+                    $phpcsFile->fixer->replaceToken(($closer - 1), $padding);
+                }
+            }
         }
 
     }//end processSingleLineCall()
@@ -222,7 +274,7 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
      * @param PHP_CodeSniffer_File $phpcsFile   The file being scanned.
      * @param int                  $stackPtr    The position of the current token
      *                                          in the stack passed in $tokens.
-     * @param int                  $openBracket The position of the openning bracket
+     * @param int                  $openBracket The position of the opening bracket
      *                                          in the stack passed in $tokens.
      * @param array                $tokens      The stack of tokens that make up
      *                                          the file.
@@ -246,27 +298,49 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
             $functionIndent = strlen($tokens[$i]['content']);
         }
 
-        // Each line between the parenthesis should be indented n spaces.
+        if ($tokens[($openBracket + 1)]['content'] !== $phpcsFile->eolChar) {
+            $error = 'Opening parenthesis of a multi-line function call must be the last content on the line';
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'ContentAfterOpenBracket');
+            if ($fix === true) {
+                $phpcsFile->fixer->addContent(
+                    $openBracket,
+                    $phpcsFile->eolChar.str_repeat(' ', ($functionIndent + $this->indent))
+                );
+            }
+        }
+
         $closeBracket = $tokens[$openBracket]['parenthesis_closer'];
-        $lastLine     = $tokens[$openBracket]['line'];
+        $prev         = $phpcsFile->findPrevious(T_WHITESPACE, ($closeBracket - 1), null, true);
+        if ($tokens[$prev]['line'] === $tokens[$closeBracket]['line']) {
+            $error = 'Closing parenthesis of a multi-line function call must be on a line by itself';
+            $fix   = $phpcsFile->addFixableError($error, $closeBracket, 'CloseBracketLine');
+            if ($fix === true) {
+                $phpcsFile->fixer->addContentBefore(
+                    $closeBracket,
+                    $phpcsFile->eolChar.str_repeat(' ', ($functionIndent + $this->indent))
+                );
+            }
+        }
+
+        // Each line between the parenthesis should be indented n spaces.
+        $lastLine = $tokens[$openBracket]['line'];
+        $exact    = true;
+        $exactEnd = null;
         for ($i = ($openBracket + 1); $i < $closeBracket; $i++) {
-            // Skip nested function calls.
-            if ($tokens[$i]['code'] === T_OPEN_PARENTHESIS) {
-                $i        = $tokens[$i]['parenthesis_closer'];
-                $lastLine = $tokens[$i]['line'];
-                continue;
+            if ($i === $exactEnd) {
+                $exact = true;
             }
 
             if ($tokens[$i]['line'] !== $lastLine) {
                 $lastLine = $tokens[$i]['line'];
 
                 // Ignore heredoc indentation.
-                if (in_array($tokens[$i]['code'], PHP_CodeSniffer_Tokens::$heredocTokens) === true) {
+                if (isset(PHP_CodeSniffer_Tokens::$heredocTokens[$tokens[$i]['code']]) === true) {
                     continue;
                 }
 
                 // Ignore multi-line string indentation.
-                if (in_array($tokens[$i]['code'], PHP_CodeSniffer_Tokens::$stringTokens) === true) {
+                if (isset(PHP_CodeSniffer_Tokens::$stringTokens[$tokens[$i]['code']]) === true) {
                     if ($tokens[$i]['code'] === $tokens[($i - 1)]['code']) {
                         continue;
                     }
@@ -278,8 +352,14 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
                 if ($tokens[$i]['code'] === T_WHITESPACE) {
                     $nextCode = $phpcsFile->findNext(T_WHITESPACE, ($i + 1), ($closeBracket + 1), true);
                     if ($tokens[$nextCode]['line'] !== $lastLine) {
-                        $error = 'Empty lines are not allowed in multi-line function calls';
-                        $phpcsFile->addError($error, $i, 'EmptyLine');
+                        if ($exact === true) {
+                            $error = 'Empty lines are not allowed in multi-line function calls';
+                            $fix   = $phpcsFile->addFixableError($error, $i, 'EmptyLine');
+                            if ($fix === true) {
+                                $phpcsFile->fixer->replaceToken($i, '');
+                            }
+                        }
+
                         continue;
                     }
                 } else {
@@ -292,7 +372,7 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
                     continue;
                 }
 
-                if ($nextCode === $closeBracket) {
+                if ($tokens[$nextCode]['line'] === $tokens[$closeBracket]['line']) {
                     // Closing brace needs to be indented to the same level
                     // as the function call.
                     $expectedIndent = $functionIndent;
@@ -300,7 +380,9 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
                     $expectedIndent = ($functionIndent + $this->indent);
                 }
 
-                if ($tokens[$i]['code'] !== T_WHITESPACE) {
+                if ($tokens[$i]['code'] !== T_WHITESPACE
+                    && $tokens[$i]['code'] !== T_DOC_COMMENT_WHITESPACE
+                ) {
                     // Just check if it is a multi-line block comment. If so, we can
                     // calculate the indent from the whitespace before the content.
                     if ($tokens[$i]['code'] === T_COMMENT
@@ -315,29 +397,57 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
                     $foundIndent = strlen($tokens[$i]['content']);
                 }
 
-                if ($expectedIndent !== $foundIndent) {
+                if ($foundIndent < $expectedIndent
+                    || ($exact === true
+                    && $expectedIndent !== $foundIndent)
+                ) {
                     $error = 'Multi-line function call not indented correctly; expected %s spaces but found %s';
                     $data  = array(
                               $expectedIndent,
                               $foundIndent,
                              );
-                    $phpcsFile->addError($error, $i, 'Indent', $data);
-                }
+
+                    $fix = $phpcsFile->addFixableError($error, $i, 'Indent', $data);
+                    if ($fix === true) {
+                        $padding = str_repeat(' ', $expectedIndent);
+                        if ($foundIndent === 0) {
+                            $phpcsFile->fixer->addContentBefore($i, $padding);
+                        } else {
+                            if ($tokens[$i]['code'] === T_COMMENT) {
+                                $comment = $padding.ltrim($tokens[$i]['content']);
+                                $phpcsFile->fixer->replaceToken($i, $comment);
+                            } else {
+                                $phpcsFile->fixer->replaceToken($i, $padding);
+                            }
+                        }
+                    }
+                }//end if
             }//end if
 
-            // Skip the rest of a closure.
-            if ($tokens[$i]['code'] === T_CLOSURE) {
-                $i        = $tokens[$i]['scope_closer'];
-                $lastLine = $tokens[$i]['line'];
+            // Turn off exact indent matching for some structures that typically
+            // define their own indentation rules.
+            if ($exact === true) {
+                if ($tokens[$i]['code'] === T_CLOSURE) {
+                    $exact    = false;
+                    $exactEnd = $tokens[$i]['scope_closer'];
+                } else if ($tokens[$i]['code'] === T_OPEN_SHORT_ARRAY) {
+                    $exact    = false;
+                    $exactEnd = $tokens[$i]['bracket_closer'];
+                } else if ($tokens[$i]['code'] === T_DOC_COMMENT_OPEN_TAG) {
+                    $exact    = false;
+                    $exactEnd = $tokens[$i]['comment_closer'];
+                } else if ($tokens[$i]['code'] === T_OPEN_PARENTHESIS) {
+                    $exact    = false;
+                    $exactEnd = $tokens[$i]['parenthesis_closer'];
+                } else if ($phpcsFile->tokenizerType === 'JS'
+                    && $tokens[$i]['code'] === T_OBJECT
+                ) {
+                    $exact    = false;
+                    $exactEnd = $tokens[$i]['bracket_closer'];
+                }
+            } else {
                 continue;
-            }
-
-            // Skip the rest of a short array.
-            if ($tokens[$i]['code'] === T_OPEN_SHORT_ARRAY) {
-                $i        = $tokens[$i]['bracket_closer'];
-                $lastLine = $tokens[$i]['line'];
-                continue;
-            }
+            }//end if
 
             if ($this->allowMultipleArguments === false && $tokens[$i]['code'] === T_COMMA) {
                 // Comma has to be the last token on the line.
@@ -346,22 +456,27 @@ class PEAR_Sniffs_Functions_FunctionCallSignatureSniff implements PHP_CodeSniffe
                     && $tokens[$i]['line'] === $tokens[$next]['line']
                 ) {
                     $error = 'Only one argument is allowed per line in a multi-line function call';
-                    $phpcsFile->addError($error, $next, 'MultipleArguments');
+                    $fix   = $phpcsFile->addFixableError($error, $next, 'MultipleArguments');
+                    if ($fix === true) {
+                        $phpcsFile->fixer->beginChangeset();
+                        for ($x = ($next - 1); $x > $i; $x--) {
+                            if ($tokens[$x]['code'] !== T_WHITESPACE) {
+                                break;
+                            }
+
+                            $phpcsFile->fixer->replaceToken($x, '');
+                        }
+
+                        $phpcsFile->fixer->addContentBefore(
+                            $next,
+                            $phpcsFile->eolChar.str_repeat(' ', ($functionIndent + $this->indent))
+                        );
+                        $phpcsFile->fixer->endChangeset();
+                    }
                 }
-            }
+            }//end if
         }//end for
 
-        if ($tokens[($openBracket + 1)]['content'] !== $phpcsFile->eolChar) {
-            $error = 'Opening parenthesis of a multi-line function call must be the last content on the line';
-            $phpcsFile->addError($error, $stackPtr, 'ContentAfterOpenBracket');
-        }
-
-        $prev = $phpcsFile->findPrevious(T_WHITESPACE, ($closeBracket - 1), null, true);
-        if ($tokens[$prev]['line'] === $tokens[$closeBracket]['line']) {
-            $error = 'Closing parenthesis of a multi-line function call must be on a line by itself';
-            $phpcsFile->addError($error, $closeBracket, 'CloseBracketLine');
-        }
-
     }//end processMultiLineCall()
 
 
