@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -64,20 +64,54 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
     {
         $tokens = $phpcsFile->getTokens();
 
-        $spaces = 0;
-        if ($tokens[($stackPtr + 1)]['code'] === T_WHITESPACE) {
+        $openBracket  = $tokens[$stackPtr]['parenthesis_opener'];
+        $closeBracket = $tokens[$stackPtr]['parenthesis_closer'];
+
+        // Must be one space after the FUNCTION keyword.
+        if ($tokens[($stackPtr + 1)]['content'] === $phpcsFile->eolChar) {
+            $spaces = 'newline';
+        } else if ($tokens[($stackPtr + 1)]['code'] === T_WHITESPACE) {
             $spaces = strlen($tokens[($stackPtr + 1)]['content']);
+        } else {
+            $spaces = 0;
         }
 
         if ($spaces !== 1) {
             $error = 'Expected 1 space after FUNCTION keyword; %s found';
             $data  = array($spaces);
-            $phpcsFile->addError($error, $stackPtr, 'SpaceAfterFunction', $data);
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceAfterFunction', $data);
+            if ($fix === true) {
+                if ($spaces === 0) {
+                    $phpcsFile->fixer->addContent($stackPtr, ' ');
+                } else {
+                    $phpcsFile->fixer->replaceToken(($stackPtr + 1), ' ');
+                }
+            }
         }
 
+        // Must be one space before the opening parenthesis. For closures, this is
+        // enforced by the first check because there is no content between the keywords
+        // and the opening parenthesis.
+        if ($tokens[$stackPtr]['code'] === T_FUNCTION) {
+            if ($tokens[($openBracket - 1)]['content'] === $phpcsFile->eolChar) {
+                $spaces = 'newline';
+            } else if ($tokens[($openBracket - 1)]['code'] === T_WHITESPACE) {
+                $spaces = strlen($tokens[($openBracket - 1)]['content']);
+            } else {
+                $spaces = 0;
+            }
+
+            if ($spaces !== 0) {
+                $error = 'Expected 0 spaces before opening parenthesis; %s found';
+                $data  = array($spaces);
+                $fix   = $phpcsFile->addFixableError($error, $openBracket, 'SpaceBeforeOpenParen', $data);
+                if ($fix === true) {
+                    $phpcsFile->fixer->replaceToken(($openBracket - 1), '');
+                }
+            }
+        }//end if
+
         // Must be one space before and after USE keyword for closures.
-        $openBracket  = $tokens[$stackPtr]['parenthesis_opener'];
-        $closeBracket = $tokens[$stackPtr]['parenthesis_closer'];
         if ($tokens[$stackPtr]['code'] === T_CLOSURE) {
             $use = $phpcsFile->findNext(T_USE, ($closeBracket + 1), $tokens[$stackPtr]['scope_opener']);
             if ($use !== false) {
@@ -92,7 +126,14 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
                 if ($length !== 1) {
                     $error = 'Expected 1 space after USE keyword; found %s';
                     $data  = array($length);
-                    $phpcsFile->addError($error, $use, 'SpaceAfterUse', $data);
+                    $fix   = $phpcsFile->addFixableError($error, $use, 'SpaceAfterUse', $data);
+                    if ($fix === true) {
+                        if ($length === 0) {
+                            $phpcsFile->fixer->addContent($use, ' ');
+                        } else {
+                            $phpcsFile->fixer->replaceToken(($use + 1), ' ');
+                        }
+                    }
                 }
 
                 if ($tokens[($use - 1)]['code'] !== T_WHITESPACE) {
@@ -106,7 +147,14 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
                 if ($length !== 1) {
                     $error = 'Expected 1 space before USE keyword; found %s';
                     $data  = array($length);
-                    $phpcsFile->addError($error, $use, 'SpaceBeforeUse', $data);
+                    $fix   = $phpcsFile->addFixableError($error, $use, 'SpaceBeforeUse', $data);
+                    if ($fix === true) {
+                        if ($length === 0) {
+                            $phpcsFile->fixer->addContentBefore($use, ' ');
+                        } else {
+                            $phpcsFile->fixer->replaceToken(($use - 1), ' ');
+                        }
+                    }
                 }
             }//end if
         }//end if
@@ -168,13 +216,14 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
             $sniff = new Generic_Sniffs_Functions_OpeningFunctionBraceBsdAllmanSniff();
         }
 
+        $sniff->checkClosures = true;
         $sniff->process($phpcsFile, $stackPtr);
 
     }//end processSingleLineDeclaration()
 
 
     /**
-     * Processes mutli-line declarations.
+     * Processes multi-line declarations.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The file being scanned.
      * @param int                  $stackPtr  The position of the current token
@@ -204,7 +253,7 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
         // The closing parenthesis must be on a new line, even
         // when checking abstract function definitions.
         $closeBracket = $tokens[$stackPtr]['parenthesis_closer'];
-        $prev = $phpcsFile->findPrevious(
+        $prev         = $phpcsFile->findPrevious(
             T_WHITESPACE,
             ($closeBracket - 1),
             null,
@@ -214,7 +263,10 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
         if ($tokens[$closeBracket]['line'] !== $tokens[$tokens[$closeBracket]['parenthesis_opener']]['line']) {
             if ($tokens[$prev]['line'] === $tokens[$closeBracket]['line']) {
                 $error = 'The closing parenthesis of a multi-line function declaration must be on a new line';
-                $phpcsFile->addError($error, $closeBracket, 'CloseBracketLine');
+                $fix   = $phpcsFile->addFixableError($error, $closeBracket, 'CloseBracketLine');
+                if ($fix === true) {
+                    $phpcsFile->fixer->addNewlineBefore($closeBracket);
+                }
             }
         }
 
@@ -237,15 +289,18 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
                 if ($tokens[$closeBracket]['line'] !== $tokens[$tokens[$closeBracket]['parenthesis_opener']]['line']) {
                     if ($tokens[$prev]['line'] === $tokens[$closeBracket]['line']) {
                         $error = 'The closing parenthesis of a multi-line use declaration must be on a new line';
-                        $phpcsFile->addError($error, $closeBracket, 'CloseBracketLine');
+                        $fix   = $phpcsFile->addFixableError($error, $closeBracket, 'UseCloseBracketLine');
+                        if ($fix === true) {
+                            $phpcsFile->fixer->addNewlineBefore($closeBracket);
+                        }
                     }
                 }
             }//end if
         }//end if
 
         // Each line between the parenthesis should be indented 4 spaces.
-        $openBracket  = $tokens[$stackPtr]['parenthesis_opener'];
-        $lastLine     = $tokens[$openBracket]['line'];
+        $openBracket = $tokens[$stackPtr]['parenthesis_opener'];
+        $lastLine    = $tokens[$openBracket]['line'];
         for ($i = ($openBracket + 1); $i < $closeBracket; $i++) {
             if ($tokens[$i]['line'] !== $lastLine) {
                 if ($i === $tokens[$stackPtr]['parenthesis_closer']
@@ -273,7 +328,16 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
                               $expectedIndent,
                               $foundIndent,
                              );
-                    $phpcsFile->addError($error, $i, 'Indent', $data);
+
+                    $fix = $phpcsFile->addFixableError($error, $i, 'Indent', $data);
+                    if ($fix === true) {
+                        $spaces = str_repeat(' ', $expectedIndent);
+                        if ($foundIndent === 0) {
+                            $phpcsFile->fixer->addContentBefore($i, $spaces);
+                        } else {
+                            $phpcsFile->fixer->replaceToken($i, $spaces);
+                        }
+                    }
                 }
 
                 $lastLine = $tokens[$i]['line'];
@@ -293,7 +357,7 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
         }//end for
 
         if (isset($tokens[$stackPtr]['scope_opener']) === true) {
-            // The openning brace needs to be one space away
+            // The opening brace needs to be one space away
             // from the closing parenthesis.
             $next = $tokens[($closeBracket + 1)];
             if ($next['code'] !== T_WHITESPACE) {
@@ -316,9 +380,17 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
                     $error .= '%s spaces';
                 }
 
-                $phpcsFile->addError($error, ($closeBracket + 1), $code, $data);
+                $fix = $phpcsFile->addFixableError($error, ($closeBracket + 1), $code, $data);
+                if ($fix === true) {
+                    if ($length === 0) {
+                        $phpcsFile->fixer->addContent($closeBracket, ' ');
+                    } else {
+                        $phpcsFile->fixer->replaceToken(($closeBracket + 1), ' ');
+                    }
+                }
+
                 return;
-            }
+            }//end if
 
             // And just in case they do something funny before the brace...
             $next = $phpcsFile->findNext(
@@ -338,5 +410,3 @@ class PEAR_Sniffs_Functions_FunctionDeclarationSniff implements PHP_CodeSniffer_
 
 
 }//end class
-
-?>
