@@ -22,17 +22,17 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PSR2_Sniffs_ControlStructures_SwitchDeclarationSniff implements PHP_CodeSniffer_Sniff
 {
 
     /**
-    * The number of spaces code should be indented.
-    *
-    * @var int
-    */
+     * The number of spaces code should be indented.
+     *
+     * @var int
+     */
     public $indent = 4;
 
 
@@ -90,12 +90,11 @@ class PSR2_Sniffs_ControlStructures_SwitchDeclarationSniff implements PHP_CodeSn
                              $expected,
                              $tokens[$nextCase]['content'],
                             );
-                $phpcsFile->addError($error, $nextCase, $type.'NotLower', $data);
-            }
 
-            if ($tokens[$nextCase]['column'] !== $caseAlignment) {
-                $error = strtoupper($type).' keyword must be indented '.$this->indent.' spaces from SWITCH keyword';
-                $phpcsFile->addError($error, $nextCase, $type.'Indent');
+                $fix = $phpcsFile->addFixableError($error, $nextCase, $type.'NotLower', $data);
+                if ($fix === true) {
+                    $phpcsFile->fixer->replaceToken($nextCase, $expected);
+                }
             }
 
             if ($type === 'case'
@@ -103,30 +102,82 @@ class PSR2_Sniffs_ControlStructures_SwitchDeclarationSniff implements PHP_CodeSn
                 || $tokens[($nextCase + 1)]['content'] !== ' ')
             ) {
                 $error = 'CASE keyword must be followed by a single space';
-                $phpcsFile->addError($error, $nextCase, 'SpacingAfterCase');
+                $fix   = $phpcsFile->addFixableError($error, $nextCase, 'SpacingAfterCase');
+                if ($fix === true) {
+                    if ($tokens[($nextCase + 1)]['code'] !== T_WHITESPACE) {
+                        $phpcsFile->fixer->addContent($nextCase, ' ');
+                    } else {
+                        $phpcsFile->fixer->replaceToken(($nextCase + 1), ' ');
+                    }
+                }
             }
 
             $opener = $tokens[$nextCase]['scope_opener'];
             if ($tokens[$opener]['code'] === T_COLON) {
                 if ($tokens[($opener - 1)]['code'] === T_WHITESPACE) {
                     $error = 'There must be no space before the colon in a '.strtoupper($type).' statement';
-                    $phpcsFile->addError($error, $nextCase, 'SpaceBeforeColon'.$type);
+                    $fix   = $phpcsFile->addFixableError($error, $nextCase, 'SpaceBeforeColon'.strtoupper($type));
+                    if ($fix === true) {
+                        $phpcsFile->fixer->replaceToken(($opener - 1), '');
+                    }
                 }
+
+                $next = $phpcsFile->findNext(T_WHITESPACE, ($opener + 1), null, true);
+                if ($tokens[$next]['line'] !== ($tokens[$opener]['line'] + 1)) {
+                    $error = 'The '.strtoupper($type).' body must start on the line following the statement';
+                    $fix   = $phpcsFile->addFixableError($error, $nextCase, 'SpaceBeforeColon'.strtoupper($type));
+                    if ($fix === true) {
+                        if ($tokens[$next]['line'] === $tokens[$opener]['line']) {
+                            $padding = str_repeat(' ', ($caseAlignment + $this->indent - 1));
+                            $phpcsFile->fixer->addContentBefore($next, $phpcsFile->eolChar.$padding);
+                        } else {
+                            $phpcsFile->fixer->beginChangeset();
+                            for ($i = ($opener + 1); $i < $next; $i++) {
+                                if ($tokens[$i]['line'] === $tokens[$next]['line']) {
+                                    break;
+                                }
+
+                                $phpcsFile->fixer->replaceToken($i, '');
+                            }
+
+                            $phpcsFile->fixer->addNewLineBefore($i);
+                            $phpcsFile->fixer->endChangeset();
+                        }
+                    }
+                }//end if
             } else {
-                $error = strtoupper($type).' statements must not be defined using curly braces';
+                $error = strtoupper($type).' statements must be defined using a colon';
                 $phpcsFile->addError($error, $nextCase, 'WrongOpener'.$type);
-            }
+            }//end if
 
             $nextCloser = $tokens[$nextCase]['scope_closer'];
             if ($tokens[$nextCloser]['scope_condition'] === $nextCase) {
                 // Only need to check some things once, even if the
                 // closer is shared between multiple case statements, or even
                 // the default case.
-                if ($tokens[$nextCloser]['column'] !== ($caseAlignment + $this->indent)) {
-                    $error = 'Terminating statement must be indented to the same level as the CASE body';
-                    $phpcsFile->addError($error, $nextCloser, 'BreakIndent');
-                }
-            }
+                $prev = $phpcsFile->findPrevious(T_WHITESPACE, ($nextCloser - 1), $nextCase, true);
+                if ($tokens[$prev]['line'] === $tokens[$nextCloser]['line']) {
+                    $error = 'Terminating statement must be on a line by itself';
+                    $fix   = $phpcsFile->addFixableError($error, $nextCloser, 'BreakNotNewLine');
+                    if ($fix === true) {
+                        $phpcsFile->fixer->addNewLine($prev);
+                        $phpcsFile->fixer->replaceToken($nextCloser, trim($tokens[$nextCloser]['content']));
+                    }
+                } else {
+                    $diff = ($caseAlignment + $this->indent - $tokens[$nextCloser]['column']);
+                    if ($diff !== 0) {
+                        $error = 'Terminating statement must be indented to the same level as the CASE body';
+                        $fix   = $phpcsFile->addFixableError($error, $nextCloser, 'BreakIndent');
+                        if ($fix === true) {
+                            if ($diff > 0) {
+                                $phpcsFile->fixer->addContentBefore($nextCloser, str_repeat(' ', $diff));
+                            } else {
+                                $phpcsFile->fixer->substrToken(($nextCloser - 1), 0, $diff);
+                            }
+                        }
+                    }
+                }//end if
+            }//end if
 
             // We only want cases from here on in.
             if ($type !== 'case') {
@@ -188,5 +239,3 @@ class PSR2_Sniffs_ControlStructures_SwitchDeclarationSniff implements PHP_CodeSn
 
 
 }//end class
-
-?>
