@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PSR2_Sniffs_Namespaces_NamespaceDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -54,7 +54,7 @@ class PSR2_Sniffs_Namespaces_NamespaceDeclarationSniff implements PHP_CodeSniffe
     {
         $tokens = $phpcsFile->getTokens();
 
-        for ($i = ($stackPtr + 1); $i < $phpcsFile->numTokens; $i++) {
+        for ($i = ($stackPtr + 1); $i < ($phpcsFile->numTokens - 1); $i++) {
             if ($tokens[$i]['line'] === $tokens[$stackPtr]['line']) {
                 continue;
             }
@@ -65,15 +65,41 @@ class PSR2_Sniffs_Namespaces_NamespaceDeclarationSniff implements PHP_CodeSniffe
         // The $i var now points to the first token on the line after the
         // namespace declaration, which must be a blank line.
         $next = $phpcsFile->findNext(T_WHITESPACE, $i, $phpcsFile->numTokens, true);
-        if ($tokens[$next]['line'] === $tokens[$i]['line']) {
-            $error = 'There must be one blank line after the namespace declaration';
-            $phpcsFile->addError($error, $stackPtr, 'BlankLineAfter');
+        if ($next === false) {
+            return;
+        }
+
+        $diff = ($tokens[$next]['line'] - $tokens[$i]['line']);
+        if ($diff === 1) {
+            return;
+        }
+
+        if ($diff < 0) {
+            $diff = 0;
+        }
+
+        $error = 'There must be one blank line after the namespace declaration';
+        $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'BlankLineAfter');
+
+        if ($fix === true) {
+            if ($diff === 0) {
+                $phpcsFile->fixer->addNewlineBefore($i);
+            } else {
+                $phpcsFile->fixer->beginChangeset();
+                for ($x = $i; $x < $next; $x++) {
+                    if ($tokens[$x]['line'] === $tokens[$next]['line']) {
+                        break;
+                    }
+
+                    $phpcsFile->fixer->replaceToken($x, '');
+                }
+
+                $phpcsFile->fixer->addNewline($i);
+                $phpcsFile->fixer->endChangeset();
+            }
         }
 
     }//end process()
 
 
 }//end class
-
-
-?>
