@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_CSS_ClassDefinitionClosingBraceSpaceSniff implements PHP_CodeSniffer_Sniff
@@ -71,9 +71,24 @@ class Squiz_Sniffs_CSS_ClassDefinitionClosingBraceSpaceSniff implements PHP_Code
             if ($found !== 1) {
                 $error = 'Expected one blank line after closing brace of class definition; %s found';
                 $data  = array($found);
-                $phpcsFile->addError($error, $stackPtr, 'SpacingAfterClose', $data);
-            }
-        }
+                $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpacingAfterClose', $data);
+
+                if ($fix === true) {
+                    if ($found === 0) {
+                        $phpcsFile->fixer->addNewline($stackPtr);
+                    } else {
+                        $nextContent = $phpcsFile->findNext(T_WHITESPACE, ($stackPtr + 1), null, true);
+                        $phpcsFile->fixer->beginChangeset();
+                        for ($i = ($stackPtr + 1); $i < ($nextContent - 1); $i++) {
+                            $phpcsFile->fixer->replaceToken($i, '');
+                        }
+
+                        $phpcsFile->fixer->addNewline($i);
+                        $phpcsFile->fixer->endChangeset();
+                    }
+                }
+            }//end if
+        }//end if
 
         // Ignore nested style definitions from here on. The spacing before the closing brace
         // (a single blank line) will be enforced by the above check, which ensures there is a
@@ -83,21 +98,25 @@ class Squiz_Sniffs_CSS_ClassDefinitionClosingBraceSpaceSniff implements PHP_Code
             ($stackPtr - 1),
             $tokens[$stackPtr]['bracket_opener']
         );
+
         if ($found !== false) {
             return;
         }
 
         $prev = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr - 1), null, true);
-        if ($prev !== false && $tokens[$prev]['line'] !== ($tokens[$stackPtr]['line'] - 1)) {
-            $num   = ($tokens[$stackPtr]['line'] - $tokens[$prev]['line'] - 1);
-            $error = 'Expected 0 blank lines before closing brace of class definition; %s found';
-            $data  = array($num);
-            $phpcsFile->addError($error, $stackPtr, 'SpacingBeforeClose', $data);
+        if ($prev === false) {
+            return;
+        }
+
+        if ($tokens[$prev]['line'] === $tokens[$stackPtr]['line']) {
+            $error = 'Closing brace of class definition must be on new line';
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'ContentBeforeClose');
+            if ($fix === true) {
+                $phpcsFile->fixer->addNewlineBefore($stackPtr);
+            }
         }
 
     }//end process()
 
 
 }//end class
-
-?>
