@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Commenting_PostStatementCommentSniff implements PHP_CodeSniffer_Sniff
@@ -91,13 +91,13 @@ class Squiz_Sniffs_Commenting_PostStatementCommentSniff implements PHP_CodeSniff
             }
         }
 
-        $error = 'Comments may not appear after statements.';
-        $phpcsFile->addError($error, $stackPtr, 'Found');
+        $error = 'Comments may not appear after statements';
+        $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'Found');
+        if ($fix === true) {
+            $phpcsFile->fixer->addNewlineBefore($stackPtr);
+        }
 
     }//end process()
 
 
 }//end class
-
-
-?>
