@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_ControlStructures_ElseIfDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -56,12 +56,12 @@ class Squiz_Sniffs_ControlStructures_ElseIfDeclarationSniff implements PHP_CodeS
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
         $error = 'Usage of ELSEIF not allowed; use ELSE IF instead';
-        $phpcsFile->addError($error, $stackPtr, 'NotAllowed');
+        $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'NotAllowed');
+        if ($fix === true) {
+            $phpcsFile->fixer->replaceToken($stackPtr, 'else if');
+        }
 
     }//end process()
 
 
 }//end class
-
-
-?>
