@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_ControlStructures_ForEachLoopDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -74,11 +74,20 @@ class Squiz_Sniffs_ControlStructures_ForEachLoopDeclarationSniff implements PHP_
         $tokens = $phpcsFile->getTokens();
 
         $openingBracket = $phpcsFile->findNext(T_OPEN_PARENTHESIS, $stackPtr);
+        if ($openingBracket === false) {
+            $error = 'Possible parse error: FOREACH has no opening parenthesis';
+            $phpcsFile->addWarning($error, $stackPtr, 'MissingParenthesis');
+            return;
+        }
+
         $closingBracket = $tokens[$openingBracket]['parenthesis_closer'];
 
         if ($this->requiredSpacesAfterOpen === 0 && $tokens[($openingBracket + 1)]['code'] === T_WHITESPACE) {
             $error = 'Space found after opening bracket of FOREACH loop';
-            $phpcsFile->addError($error, $stackPtr, 'SpaceAfterOpen');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceAfterOpen');
+            if ($fix === true) {
+                $phpcsFile->fixer->replaceToken(($openingBracket + 1), '');
+            }
         } else if ($this->requiredSpacesAfterOpen > 0) {
             $spaceAfterOpen = 0;
             if ($tokens[($openingBracket + 1)]['code'] === T_WHITESPACE) {
@@ -91,13 +100,24 @@ class Squiz_Sniffs_ControlStructures_ForEachLoopDeclarationSniff implements PHP_
                           $this->requiredSpacesAfterOpen,
                           $spaceAfterOpen,
                          );
-                $phpcsFile->addError($error, $stackPtr, 'SpacingAfterOpen', $data);
+                $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpacingAfterOpen', $data);
+                if ($fix === true) {
+                    $padding = str_repeat(' ', $this->requiredSpacesAfterOpen);
+                    if ($spaceAfterOpen === 0) {
+                        $phpcsFile->fixer->addContent($openingBracket, $padding);
+                    } else {
+                        $phpcsFile->fixer->replaceToken(($openingBracket + 1), $padding);
+                    }
+                }
             }
-        }
+        }//end if
 
         if ($this->requiredSpacesBeforeClose === 0 && $tokens[($closingBracket - 1)]['code'] === T_WHITESPACE) {
             $error = 'Space found before closing bracket of FOREACH loop';
-            $phpcsFile->addError($error, $stackPtr, 'SpaceBeforeClose');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceBeforeClose');
+            if ($fix === true) {
+                $phpcsFile->fixer->replaceToken(($closingBracket - 1), '');
+            }
         } else if ($this->requiredSpacesBeforeClose > 0) {
             $spaceBeforeClose = 0;
             if ($tokens[($closingBracket - 1)]['code'] === T_WHITESPACE) {
@@ -110,11 +130,25 @@ class Squiz_Sniffs_ControlStructures_ForEachLoopDeclarationSniff implements PHP_
                           $this->requiredSpacesBeforeClose,
                           $spaceBeforeClose,
                          );
-                $phpcsFile->addError($error, $stackPtr, 'SpaceBeforeClose', $data);
+                $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'SpaceBeforeClose', $data);
+                if ($fix === true) {
+                    $padding = str_repeat(' ', $this->requiredSpacesBeforeClose);
+                    if ($spaceBeforeClose === 0) {
+                        $phpcsFile->fixer->addContentBefore($closingBracket, $padding);
+                    } else {
+                        $phpcsFile->fixer->replaceToken(($closingBracket - 1), $padding);
+                    }
+                }
             }
-        }
+        }//end if
 
         $asToken = $phpcsFile->findNext(T_AS, $openingBracket);
+        if ($asToken === false) {
+            $error = 'Possible parse error: FOREACH has no AS statement';
+            $phpcsFile->addWarning($error, $stackPtr, 'MissingAs');
+            return;
+        }
+
         $content = $tokens[$asToken]['content'];
         if ($content !== strtolower($content)) {
             $expected = strtolower($content);
@@ -123,58 +157,86 @@ class Squiz_Sniffs_ControlStructures_ForEachLoopDeclarationSniff implements PHP_
                          $expected,
                          $content,
                         );
-            $phpcsFile->addError($error, $stackPtr, 'AsNotLower', $data);
+
+            $fix = $phpcsFile->addFixableError($error, $asToken, 'AsNotLower', $data);
+            if ($fix === true) {
+                $phpcsFile->fixer->replaceToken($asToken, $expected);
+            }
         }
 
-        $doubleArrow = $phpcsFile->findNext(T_DOUBLE_ARROW, $openingBracket, $closingBracket);
+        $doubleArrow = $phpcsFile->findNext(T_DOUBLE_ARROW, $asToken, $closingBracket);
 
         if ($doubleArrow !== false) {
             if ($tokens[($doubleArrow - 1)]['code'] !== T_WHITESPACE) {
                 $error = 'Expected 1 space before "=>"; 0 found';
-                $phpcsFile->addError($error, $stackPtr, 'NoSpaceBeforeArrow');
+                $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'NoSpaceBeforeArrow');
+                if ($fix === true) {
+                    $phpcsFile->fixer->addContentBefore($doubleArrow, ' ');
+                }
             } else {
                 if (strlen($tokens[($doubleArrow - 1)]['content']) !== 1) {
                     $spaces = strlen($tokens[($doubleArrow - 1)]['content']);
                     $error  = 'Expected 1 space before "=>"; %s found';
                     $data   = array($spaces);
-                    $phpcsFile->addError($error, $stackPtr, 'SpacingBeforeArrow', $data);
+                    $fix    = $phpcsFile->addFixableError($error, $stackPtr, 'SpacingBeforeArrow', $data);
+                    if ($fix === true) {
+                        $phpcsFile->fixer->replaceToken(($doubleArrow - 1), ' ');
+                    }
                 }
             }
 
             if ($tokens[($doubleArrow + 1)]['code'] !== T_WHITESPACE) {
                 $error = 'Expected 1 space after "=>"; 0 found';
-                $phpcsFile->addError($error, $stackPtr, 'NoSpaceAfterArrow');
+                $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'NoSpaceAfterArrow');
+                if ($fix === true) {
+                    $phpcsFile->fixer->addContent($doubleArrow, ' ');
+                }
             } else {
                 if (strlen($tokens[($doubleArrow + 1)]['content']) !== 1) {
                     $spaces = strlen($tokens[($doubleArrow + 1)]['content']);
                     $error  = 'Expected 1 space after "=>"; %s found';
                     $data   = array($spaces);
-                    $phpcsFile->addError($error, $stackPtr, 'SpacingAfterArrow', $data);
+                    $fix    = $phpcsFile->addFixableError($error, $stackPtr, 'SpacingAfterArrow', $data);
+                    if ($fix === true) {
+                        $phpcsFile->fixer->replaceToken(($doubleArrow + 1), ' ');
+                    }
                 }
             }
         }//end if
 
         if ($tokens[($asToken - 1)]['code'] !== T_WHITESPACE) {
             $error = 'Expected 1 space before "as"; 0 found';
-            $phpcsFile->addError($error, $stackPtr, 'NoSpaceBeforeAs');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'NoSpaceBeforeAs');
+            if ($fix === true) {
+                $phpcsFile->fixer->addContentBefore($asToken, ' ');
+            }
         } else {
             if (strlen($tokens[($asToken - 1)]['content']) !== 1) {
                 $spaces = strlen($tokens[($asToken - 1)]['content']);
                 $error  = 'Expected 1 space before "as"; %s found';
                 $data   = array($spaces);
-                $phpcsFile->addError($error, $stackPtr, 'SpacingBeforeAs', $data);
+                $fix    = $phpcsFile->addFixableError($error, $stackPtr, 'SpacingBeforeAs', $data);
+                if ($fix === true) {
+                    $phpcsFile->fixer->replaceToken(($asToken - 1), ' ');
+                }
             }
         }
 
         if ($tokens[($asToken + 1)]['code'] !== T_WHITESPACE) {
             $error = 'Expected 1 space after "as"; 0 found';
-            $phpcsFile->addError($error, $stackPtr, 'NoSpaceAfterAs');
+            $fix   = $phpcsFile->addFixableError($error, $stackPtr, 'NoSpaceAfterAs');
+            if ($fix === true) {
+                $phpcsFile->fixer->addContent($asToken, ' ');
+            }
         } else {
             if (strlen($tokens[($asToken + 1)]['content']) !== 1) {
                 $spaces = strlen($tokens[($asToken + 1)]['content']);
                 $error  = 'Expected 1 space after "as"; %s found';
                 $data   = array($spaces);
-                $phpcsFile->addError($error, $stackPtr, 'SpacingAfterAs', $data);
+                $fix    = $phpcsFile->addFixableError($error, $stackPtr, 'SpacingAfterAs', $data);
+                if ($fix === true) {
+                    $phpcsFile->fixer->replaceToken(($asToken + 1), ' ');
+                }
             }
         }
 
