@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_ControlStructures_InlineIfDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -56,26 +56,21 @@ class Squiz_Sniffs_ControlStructures_InlineIfDeclarationSniff implements PHP_Cod
     {
         $tokens = $phpcsFile->getTokens();
 
-        // Find the opening bracket of the inline IF.
-        $i = 0;
+        $openBracket  = null;
+        $closeBracket = null;
         if (isset($tokens[$stackPtr]['nested_parenthesis']) === true) {
-            $parens = $tokens[$stackPtr]['nested_parenthesis'];
-            $i      = array_pop($parens);
-            if (isset($tokens[$i]['parenthesis_owner']) === true) {
-                // The parenthesis are owned by a token like an array or
-                // function, so are not just used for grouping.
-                $i = 0;
-            }
+            $parens       = $tokens[$stackPtr]['nested_parenthesis'];
+            $openBracket  = array_pop($parens);
+            $closeBracket = $tokens[$openBracket]['parenthesis_closer'];
         }
 
-        if ($i <= 0) {
-            // Could not find the beginning of the statement. Probably not
-            // wrapped with brackets, so assume it ends with a
-            // semicolon (end of statement) or comma (end of array value).
-            $else         = $phpcsFile->findNext(T_INLINE_ELSE, ($stackPtr + 1));
-            $statementEnd = $phpcsFile->findNext(array(T_SEMICOLON, T_COMMA), ($else + 1));
-        } else {
-            $statementEnd = $tokens[$i]['parenthesis_closer'];
+        // Find the beginning of the statement. If we don't find a
+        // semicolon (end of statement) or comma (end of array value)
+        // then assume the content before the closing parenthesis is the end.
+        $else         = $phpcsFile->findNext(T_INLINE_ELSE, ($stackPtr + 1));
+        $statementEnd = $phpcsFile->findNext(array(T_SEMICOLON, T_COMMA), ($else + 1), $closeBracket);
+        if ($statementEnd === false) {
+            $statementEnd = $phpcsFile->findPrevious(T_WHITESPACE, ($closeBracket - 1), null, true);
         }
 
         // Make sure it's all on the same line.
@@ -131,6 +126,3 @@ class Squiz_Sniffs_ControlStructures_InlineIfDeclarationSniff implements PHP_Cod
 
 
 }//end class
-
-
-?>
