@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Files_FileExtensionSniff implements PHP_CodeSniffer_Sniff
@@ -50,40 +50,34 @@ class Squiz_Sniffs_Files_FileExtensionSniff implements PHP_CodeSniffer_Sniff
      * @param int                  $stackPtr  The position of the current token in the
      *                                        stack passed in $tokens.
      *
-     * @return void
+     * @return int
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
-        $tokens = $phpcsFile->getTokens();
-
-        // Make sure this is the first PHP open tag so we don't process
-        // the same file twice.
-        $prevOpenTag = $phpcsFile->findPrevious(T_OPEN_TAG, ($stackPtr - 1));
-        if ($prevOpenTag !== false) {
-            return;
-        }
-
+        $tokens    = $phpcsFile->getTokens();
         $fileName  = $phpcsFile->getFileName();
         $extension = substr($fileName, strrpos($fileName, '.'));
         $nextClass = $phpcsFile->findNext(array(T_CLASS, T_INTERFACE, T_TRAIT), $stackPtr);
 
-        if ($extension === '.php') {
-            if ($nextClass !== false) {
+        if ($nextClass !== false) {
+            $phpcsFile->recordMetric($stackPtr, 'File extension for class files', $extension);
+            if ($extension === '.php') {
                 $error = '%s found in ".php" file; use ".inc" extension instead';
                 $data  = array(ucfirst($tokens[$nextClass]['content']));
                 $phpcsFile->addError($error, $stackPtr, 'ClassFound', $data);
             }
-        } else if ($extension === '.inc') {
-            if ($nextClass === false) {
+        } else {
+            $phpcsFile->recordMetric($stackPtr, 'File extension for non-class files', $extension);
+            if ($extension === '.inc') {
                 $error = 'No interface or class found in ".inc" file; use ".php" extension instead';
                 $phpcsFile->addError($error, $stackPtr, 'NoClass');
             }
         }
 
+        // Ignore the rest of the file.
+        return ($phpcsFile->numTokens + 1);
+
     }//end process()
 
 
 }//end class
-
-
-?>
