@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
@@ -55,7 +55,7 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
      */
     public function register()
     {
-        return PHP_CodeSniffer_Tokens::$commentTokens;
+        return array(T_COMMENT);
 
     }//end register()
 
@@ -141,15 +141,23 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
         // of errors that don't mean anything, so ignore them.
         $oldErrors = ini_get('error_reporting');
         ini_set('error_reporting', 0);
-        $stringTokens = PHP_CodeSniffer_File::tokenizeString($content, $phpcsFile->tokenizer, $phpcsFile->eolChar);
+        try {
+            $stringTokens = PHP_CodeSniffer_File::tokenizeString($content, $phpcsFile->tokenizer, $phpcsFile->eolChar);
+        } catch (PHP_CodeSniffer_Exception $e) {
+            // We couldn't check the comment, so ignore it.
+            ini_set('error_reporting', $oldErrors);
+            return;
+        }
+
         ini_set('error_reporting', $oldErrors);
 
         $emptyTokens = array(
-                        T_WHITESPACE,
-                        T_STRING,
-                        T_STRING_CONCAT,
-                        T_ENCAPSED_AND_WHITESPACE,
-                        T_NONE,
+                        T_WHITESPACE              => true,
+                        T_STRING                  => true,
+                        T_STRING_CONCAT           => true,
+                        T_ENCAPSED_AND_WHITESPACE => true,
+                        T_NONE                    => true,
+                        T_COMMENT                 => true,
                        );
 
         $numTokens = count($stringTokens);
@@ -175,7 +183,9 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
 
         // Second last token is always whitespace or a comment, depending
         // on the code inside the comment.
-        if (in_array($stringTokens[($numTokens - 2)]['code'], PHP_CodeSniffer_Tokens::$emptyTokens) === false) {
+        if ($phpcsFile->tokenizerType === 'PHP'
+            && isset(PHP_CodeSniffer_Tokens::$emptyTokens[$stringTokens[($numTokens - 2)]['code']]) === false
+        ) {
             return;
         }
 
@@ -184,11 +194,12 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
         $numCode     = 0;
 
         for ($i = 0; $i < $numTokens; $i++) {
-            if (in_array($stringTokens[$i]['code'], $emptyTokens) === true) {
+            if (isset($emptyTokens[$stringTokens[$i]['code']]) === true) {
                 // Looks like comment.
                 $numComment++;
-            } else if (in_array($stringTokens[$i]['code'], PHP_CodeSniffer_Tokens::$comparisonTokens)
-                || in_array($stringTokens[$i]['code'], PHP_CodeSniffer_Tokens::$arithmeticTokens)
+            } else if (in_array($stringTokens[$i]['code'], PHP_CodeSniffer_Tokens::$comparisonTokens) === true
+                || in_array($stringTokens[$i]['code'], PHP_CodeSniffer_Tokens::$arithmeticTokens) === true
+                || $stringTokens[$i]['code'] === T_GOTO_LABEL
             ) {
                 // Commented out HTML/XML and other docs contain a lot of these
                 // characters, so it is best to not use them directly.
@@ -224,5 +235,3 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
 
 
 }//end class
-
-?>
