@@ -26,7 +26,7 @@ if (class_exists('Generic_Sniffs_PHP_ForbiddenFunctionsSniff', true) === false)
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_PHP_DiscouragedFunctionsSniff extends Generic_Sniffs_PHP_ForbiddenFunctionsSniff
@@ -40,10 +40,11 @@ class Squiz_Sniffs_PHP_DiscouragedFunctionsSniff extends Generic_Sniffs_PHP_Forb
      *
      * @var array(string => string|null)
      */
-    protected $forbiddenFunctions = array(
-                                     'error_log' => null,
-                                     'print_r'   => null,
-                                    );
+    public $forbiddenFunctions = array(
+                                  'error_log' => null,
+                                  'print_r'   => null,
+                                  'var_dump'  => null,
+                                 );
 
     /**
      * If true, an error will be thrown; otherwise a warning.
@@ -53,5 +54,3 @@ class Squiz_Sniffs_PHP_DiscouragedFunctionsSniff extends Generic_Sniffs_PHP_Forb
     public $error = false;
 
 }//end class
-
-?>
