@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_PHP_LowercasePHPFunctionsSniff implements PHP_CodeSniffer_Sniff
@@ -73,12 +73,12 @@ class Squiz_Sniffs_PHP_LowercasePHPFunctionsSniff implements PHP_CodeSniffer_Sni
             // Function declaration, not a function call.
             return;
         }
-        
+
         if ($tokens[$prev]['code'] === T_NS_SEPARATOR) {
             // Namespaced class/function, not an inbuilt function.
             return;
         }
-        
+
         if ($tokens[$prev]['code'] === T_NEW) {
             // Object creation, not an inbuilt function.
             return;
@@ -109,12 +109,14 @@ class Squiz_Sniffs_PHP_LowercasePHPFunctionsSniff implements PHP_CodeSniffer_Sni
                       strtolower($content),
                       $content,
                      );
-            $phpcsFile->addError($error, $stackPtr, 'CallUppercase', $data);
+
+            $fix = $phpcsFile->addFixableError($error, $stackPtr, 'CallUppercase', $data);
+            if ($fix === true) {
+                $phpcsFile->fixer->replaceToken($stackPtr, strtolower($content));
+            }
         }
 
     }//end process()
 
 
 }//end class
-
-?>
