@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSniffer_Sniff
@@ -57,6 +57,8 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
                 T_DO,
                 T_ELSE,
                 T_ELSEIF,
+                T_TRY,
+                T_CATCH,
                );
 
     }//end register()
@@ -75,23 +77,47 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
     {
         $tokens = $phpcsFile->getTokens();
 
-        if (isset($tokens[$stackPtr]['parenthesis_opener']) === true) {
+        if (isset($tokens[$stackPtr]['parenthesis_opener']) === true
+            && isset($tokens[$stackPtr]['parenthesis_closer']) === true
+        ) {
             $parenOpener = $tokens[$stackPtr]['parenthesis_opener'];
             $parenCloser = $tokens[$stackPtr]['parenthesis_closer'];
             if ($tokens[($parenOpener + 1)]['code'] === T_WHITESPACE) {
-                $gap   = strlen($tokens[($parenOpener + 1)]['content']);
+                $gap   = $tokens[($parenOpener + 1)]['length'];
                 $error = 'Expected 0 spaces after opening bracket; %s found';
                 $data  = array($gap);
-                $phpcsFile->addError($error, ($parenOpener + 1), 'SpacingAfterOpenBrace', $data);
+                $fix   = $phpcsFile->addFixableError($error, ($parenOpener + 1), 'SpacingAfterOpenBrace', $data);
+                if ($fix === true) {
+                    $phpcsFile->fixer->replaceToken(($parenOpener + 1), '');
+                }
+
+                if ($gap === 0) {
+                    $phpcsFile->recordMetric($stackPtr, 'Spaces after control structure open parenthesis', 'newline');
+                } else {
+                    $phpcsFile->recordMetric($stackPtr, 'Spaces after control structure open parenthesis', $gap);
+                }
+            } else {
+                $phpcsFile->recordMetric($stackPtr, 'Spaces after control structure open parenthesis', 0);
             }
 
             if ($tokens[$parenOpener]['line'] === $tokens[$parenCloser]['line']
                 && $tokens[($parenCloser - 1)]['code'] === T_WHITESPACE
             ) {
-                $gap   = strlen($tokens[($parenCloser - 1)]['content']);
+                $gap   = $tokens[($parenCloser - 1)]['length'];
                 $error = 'Expected 0 spaces before closing bracket; %s found';
                 $data  = array($gap);
-                $phpcsFile->addError($error, ($parenCloser - 1), 'SpaceBeforeCloseBrace', $data);
+                $fix   = $phpcsFile->addFixableError($error, ($parenCloser - 1), 'SpaceBeforeCloseBrace', $data);
+                if ($fix === true) {
+                    $phpcsFile->fixer->replaceToken(($parenCloser - 1), '');
+                }
+
+                if ($gap === 0) {
+                    $phpcsFile->recordMetric($stackPtr, 'Spaces before control structure close parenthesis', 'newline');
+                } else {
+                    $phpcsFile->recordMetric($stackPtr, 'Spaces before control structure close parenthesis', $gap);
+                }
+            } else {
+                $phpcsFile->recordMetric($stackPtr, 'Spaces before control structure close parenthesis', 0);
             }
         }//end if
 
@@ -102,16 +128,27 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
         $scopeOpener = $tokens[$stackPtr]['scope_opener'];
         $scopeCloser = $tokens[$stackPtr]['scope_closer'];
 
-        $firstContent = $phpcsFile->findNext(
-            T_WHITESPACE,
-            ($scopeOpener + 1),
-            null,
-            true
-        );
+        for ($firstContent = ($scopeOpener + 1); $firstContent < $phpcsFile->numTokens; $firstContent++) {
+            if ($tokens[$firstContent]['code'] !== T_WHITESPACE) {
+                break;
+            }
+        }
 
-        if ($tokens[$firstContent]['line'] !== ($tokens[$scopeOpener]['line'] + 1)) {
+        if ($tokens[$firstContent]['line'] >= ($tokens[$scopeOpener]['line'] + 2)) {
             $error = 'Blank line found at start of control structure';
-            $phpcsFile->addError($error, $scopeOpener, 'SpacingBeforeOpen');
+            $fix   = $phpcsFile->addFixableError($error, $scopeOpener, 'SpacingAfterOpen');
+
+            if ($fix === true) {
+                $phpcsFile->fixer->beginChangeset();
+                $i = ($scopeOpener + 1);
+                while ($tokens[$i]['line'] !== $tokens[$firstContent]['line']) {
+                    $phpcsFile->fixer->replaceToken($i, '');
+                    $i++;
+                }
+
+                $phpcsFile->fixer->addNewline($scopeOpener);
+                $phpcsFile->fixer->endChangeset();
+            }
         }
 
         if ($firstContent !== $scopeCloser) {
@@ -122,7 +159,7 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
                 true
             );
 
-            if ($tokens[$lastContent]['line'] !== ($tokens[$scopeCloser]['line'] - 1)) {
+            if ($tokens[$lastContent]['line'] <= ($tokens[$scopeCloser]['line'] - 2)) {
                 $errorToken = $scopeCloser;
                 for ($i = ($scopeCloser - 1); $i > $lastContent; $i--) {
                     if ($tokens[$i]['line'] < $tokens[$scopeCloser]['line']) {
@@ -132,9 +169,27 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
                 }
 
                 $error = 'Blank line found at end of control structure';
-                $phpcsFile->addError($error, $errorToken, 'SpacingAfterClose');
-            }
-        }
+                $fix   = $phpcsFile->addFixableError($error, $errorToken, 'SpacingBeforeClose');
+
+                if ($fix === true) {
+                    $phpcsFile->fixer->beginChangeset();
+                    $i = ($scopeCloser - 1);
+                    for ($i = ($scopeCloser - 1); $i > $lastContent; $i--) {
+                        if ($tokens[$i]['line'] === $tokens[$scopeCloser]['line']) {
+                            continue;
+                        }
+
+                        if ($tokens[$i]['line'] === $tokens[$lastContent]['line']) {
+                            break;
+                        }
+
+                        $phpcsFile->fixer->replaceToken($i, '');
+                    }
+
+                    $phpcsFile->fixer->endChangeset();
+                }
+            }//end if
+        }//end if
 
         $trailingContent = $phpcsFile->findNext(
             T_WHITESPACE,
@@ -145,7 +200,7 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
 
         if ($tokens[$trailingContent]['code'] === T_COMMENT) {
             // Special exception for code where the comment about
-            // and ELSE or ELSEIF is written between the control structures.
+            // an ELSE or ELSEIF is written between the control structures.
             $nextCode = $phpcsFile->findNext(
                 PHP_CodeSniffer_Tokens::$emptyTokens,
                 ($scopeCloser + 1),
@@ -167,6 +222,13 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
             }
         }
 
+        if ($tokens[$trailingContent]['code'] === T_WHILE
+            && $tokens[$stackPtr]['code'] === T_DO
+        ) {
+            // DO with WHILE.
+            return;
+        }
+
         if ($tokens[$trailingContent]['code'] === T_CLOSE_TAG) {
             // At the end of the script or embedded code.
             return;
@@ -174,6 +236,8 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
 
         if (isset($tokens[$trailingContent]['scope_condition']) === true
             && $tokens[$trailingContent]['scope_condition'] !== $trailingContent
+            && isset($tokens[$trailingContent]['scope_opener']) === true
+            && $tokens[$trailingContent]['scope_opener'] !== $trailingContent
         ) {
             // Another control structure's closing brace.
             $owner = $tokens[$trailingContent]['scope_condition'];
@@ -183,21 +247,43 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
                 return;
             }
 
+            if ($tokens[$owner]['code'] === T_CLOSURE
+                && ($phpcsFile->hasCondition($stackPtr, T_FUNCTION) === true
+                || $phpcsFile->hasCondition($stackPtr, T_CLOSURE) === true
+                || isset($tokens[$stackPtr]['nested_parenthesis']) === true)
+            ) {
+                return;
+            }
+
             if ($tokens[$trailingContent]['line'] !== ($tokens[$scopeCloser]['line'] + 1)) {
                 $error = 'Blank line found after control structure';
-                $phpcsFile->addError($error, $scopeCloser, 'LineAfterClose');
+                $fix   = $phpcsFile->addFixableError($error, $scopeCloser, 'LineAfterClose');
+
+                if ($fix === true) {
+                    $phpcsFile->fixer->beginChangeset();
+                    $i = ($scopeCloser + 1);
+                    while ($tokens[$i]['line'] !== $tokens[$trailingContent]['line']) {
+                        $phpcsFile->fixer->replaceToken($i, '');
+                        $i++;
+                    }
+
+                    $phpcsFile->fixer->addNewline($scopeCloser);
+                    $phpcsFile->fixer->endChangeset();
+                }
             }
         } else if ($tokens[$trailingContent]['code'] !== T_ELSE
             && $tokens[$trailingContent]['code'] !== T_ELSEIF
+            && $tokens[$trailingContent]['code'] !== T_CATCH
             && $tokens[$trailingContent]['line'] === ($tokens[$scopeCloser]['line'] + 1)
         ) {
             $error = 'No blank line found after control structure';
-            $phpcsFile->addError($error, $scopeCloser, 'NoLineAfterClose');
-        }
+            $fix   = $phpcsFile->addFixableError($error, $scopeCloser, 'NoLineAfterClose');
+            if ($fix === true) {
+                $phpcsFile->fixer->addNewline($scopeCloser);
+            }
+        }//end if
 
     }//end process()
 
 
 }//end class
-
-?>
