@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_WhiteSpace_FunctionSpacingSniff implements PHP_CodeSniffer_Sniff
@@ -70,33 +70,34 @@ class Squiz_Sniffs_WhiteSpace_FunctionSpacingSniff implements PHP_CodeSniffer_Sn
         */
 
         if (isset($tokens[$stackPtr]['scope_closer']) === false) {
-            // Must be an interface method, so the closer is the semi-colon.
+            // Must be an interface method, so the closer is the semicolon.
             $closer = $phpcsFile->findNext(T_SEMICOLON, $stackPtr);
         } else {
             $closer = $tokens[$stackPtr]['scope_closer'];
         }
 
-        $nextLineToken = null;
-        for ($i = $closer; $i < $phpcsFile->numTokens; $i++) {
-            if (strpos($tokens[$i]['content'], $phpcsFile->eolChar) === false) {
-                continue;
-            } else {
-                $nextLineToken = ($i + 1);
+        // Allow for comments on the same line as the closer.
+        for ($nextLineToken = ($closer + 1); $nextLineToken < $phpcsFile->numTokens; $nextLineToken++) {
+            if ($tokens[$nextLineToken]['line'] !== $tokens[$closer]['line']) {
                 break;
             }
         }
 
-        if (is_null($nextLineToken) === true) {
-            // Never found the next line, which means
-            // there are 0 blank lines after the function.
-            $foundLines = 0;
+        $foundLines = 0;
+        if ($nextLineToken === ($phpcsFile->numTokens - 1)) {
+            // We are at the end of the file.
+            // Don't check spacing after the function because this
+            // should be done by an EOF sniff.
+            $foundLines = $this->spacing;
         } else {
-            $nextContent = $phpcsFile->findNext(array(T_WHITESPACE), ($nextLineToken + 1), null, true);
+            $nextContent = $phpcsFile->findNext(T_WHITESPACE, $nextLineToken, null, true);
             if ($nextContent === false) {
                 // We are at the end of the file.
-                $foundLines = 0;
+                // Don't check spacing after the function because this
+                // should be done by an EOF sniff.
+                $foundLines = $this->spacing;
             } else {
-                $foundLines = ($tokens[$nextContent]['line'] - $tokens[$nextLineToken]['line']);
+                $foundLines += ($tokens[$nextContent]['line'] - $tokens[$nextLineToken]['line']);
             }
         }
 
@@ -111,8 +112,22 @@ class Squiz_Sniffs_WhiteSpace_FunctionSpacingSniff implements PHP_CodeSniffer_Sn
                        $this->spacing,
                        $foundLines,
                       );
-            $phpcsFile->addError($error, $closer, 'After', $data);
-        }
+
+            $fix = $phpcsFile->addFixableError($error, $closer, 'After', $data);
+            if ($fix === true) {
+                $phpcsFile->fixer->beginChangeset();
+                for ($i = $nextLineToken; $i <= $nextContent; $i++) {
+                    if ($tokens[$i]['line'] === $tokens[$nextContent]['line']) {
+                        $phpcsFile->fixer->addContentBefore($i, str_repeat($phpcsFile->eolChar, $this->spacing));
+                        break;
+                    }
+
+                    $phpcsFile->fixer->replaceToken($i, '');
+                }
+
+                $phpcsFile->fixer->endChangeset();
+            }//end if
+        }//end if
 
         /*
             Check the number of blank lines
@@ -132,18 +147,26 @@ class Squiz_Sniffs_WhiteSpace_FunctionSpacingSniff implements PHP_CodeSniffer_Sn
         if (is_null($prevLineToken) === true) {
             // Never found the previous line, which means
             // there are 0 blank lines before the function.
-            $foundLines = 0;
+            $foundLines  = 0;
+            $prevContent = 0;
         } else {
-            $prevContent = $phpcsFile->findPrevious(array(T_WHITESPACE, T_DOC_COMMENT), $prevLineToken, null, true);
+            $currentLine = $tokens[$stackPtr]['line'];
+
+            $prevContent = $phpcsFile->findPrevious(T_WHITESPACE, $prevLineToken, null, true);
+            if ($tokens[$prevContent]['code'] === T_DOC_COMMENT_CLOSE_TAG
+                && $tokens[$prevContent]['line'] === ($currentLine - 1)
+            ) {
+                // Account for function comments.
+                $prevContent = $phpcsFile->findPrevious(T_WHITESPACE, ($tokens[$prevContent]['comment_opener'] - 1), null, true);
+            }
 
             // Before we throw an error, check that we are not throwing an error
             // for another function. We don't want to error for no blank lines after
             // the previous function and no blank lines before this one as well.
-            $currentLine = $tokens[$stackPtr]['line'];
-            $prevLine    = ($tokens[$prevContent]['line'] - 1);
-            $i           = ($stackPtr - 1);
-            $foundLines  = 0;
-            while ($currentLine != $prevLine && $currentLine > 1 && $i > 0) {
+            $prevLine   = ($tokens[$prevContent]['line'] - 1);
+            $i          = ($stackPtr - 1);
+            $foundLines = 0;
+            while ($currentLine !== $prevLine && $currentLine > 1 && $i > 0) {
                 if (isset($tokens[$i]['scope_condition']) === true) {
                     $scopeCondition = $tokens[$i]['scope_condition'];
                     if ($tokens[$scopeCondition]['code'] === T_FUNCTION) {
@@ -182,12 +205,35 @@ class Squiz_Sniffs_WhiteSpace_FunctionSpacingSniff implements PHP_CodeSniffer_Sn
                        $this->spacing,
                        $foundLines,
                       );
-            $phpcsFile->addError($error, $stackPtr, 'Before', $data);
-        }
+
+            $fix = $phpcsFile->addFixableError($error, $stackPtr, 'Before', $data);
+            if ($fix === true) {
+                if ($prevContent === 0) {
+                    $nextSpace = 0;
+                } else {
+                    $nextSpace = $phpcsFile->findNext(T_WHITESPACE, ($prevContent + 1), $stackPtr);
+                    if ($nextSpace === false) {
+                        $nextSpace = ($stackPtr - 1);
+                    }
+                }
+
+                if ($foundLines < $this->spacing) {
+                    $padding = str_repeat($phpcsFile->eolChar, ($this->spacing - $foundLines));
+                    $phpcsFile->fixer->addContent($nextSpace, $padding);
+                } else {
+                    $nextContent = $phpcsFile->findNext(T_WHITESPACE, ($nextSpace + 1), null, true);
+                    $phpcsFile->fixer->beginChangeset();
+                    for ($i = $nextSpace; $i < ($nextContent - 1); $i++) {
+                        $phpcsFile->fixer->replaceToken($i, '');
+                    }
+
+                    $phpcsFile->fixer->replaceToken($i, str_repeat($phpcsFile->eolChar, $this->spacing));
+                    $phpcsFile->fixer->endChangeset();
+                }
+            }//end if
+        }//end if
 
     }//end process()
 
 
 }//end class
-
-?>
