@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.5
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_WhiteSpace_ScopeClosingBraceSniff implements PHP_CodeSniffer_Sniff
@@ -66,45 +66,49 @@ class Squiz_Sniffs_WhiteSpace_ScopeClosingBraceSniff implements PHP_CodeSniffer_
         // as if this is a method with tokens before it (public, static etc)
         // or an if with an else before it, then we need to start the scope
         // checking from there, rather than the current token.
-        $lineStart = ($stackPtr - 1);
-        for ($lineStart; $lineStart > 0; $lineStart--) {
-            if (strpos($tokens[$lineStart]['content'], $phpcsFile->eolChar) !== false) {
-                break;
-            }
-        }
-
-        // We found a new line, now go forward and find the
-        // first non-whitespace token.
-        $lineStart = $phpcsFile->findNext(array(T_WHITESPACE), ($lineStart + 1), null, true);
+        $lineStart = $phpcsFile->findFirstOnLine(T_WHITESPACE, $stackPtr, true);
 
         $startColumn = $tokens[$lineStart]['column'];
         $scopeStart  = $tokens[$stackPtr]['scope_opener'];
         $scopeEnd    = $tokens[$stackPtr]['scope_closer'];
 
         // Check that the closing brace is on it's own line.
-        $lastContent = $phpcsFile->findPrevious(array(T_WHITESPACE), ($scopeEnd - 1), $scopeStart, true);
+        $lastContent = $phpcsFile->findPrevious(array(T_WHITESPACE, T_OPEN_TAG), ($scopeEnd - 1), $scopeStart, true);
         if ($tokens[$lastContent]['line'] === $tokens[$scopeEnd]['line']) {
             $error = 'Closing brace must be on a line by itself';
-            $phpcsFile->addError($error, $scopeEnd, 'ContentBefore');
+            $fix   = $phpcsFile->addFixableError($error, $scopeEnd, 'ContentBefore');
+            if ($fix === true) {
+                $phpcsFile->fixer->addNewlineBefore($scopeEnd);
+            }
+
             return;
         }
 
         // Check now that the closing brace is lined up correctly.
-        $braceIndent = $tokens[$scopeEnd]['column'];
-        if (in_array($tokens[$stackPtr]['code'], array(T_CASE, T_DEFAULT)) === false) {
-            if ($braceIndent !== $startColumn) {
-                $error = 'Closing brace indented incorrectly; expected %s spaces, found %s';
-                $data  = array(
-                          ($startColumn - 1),
-                          ($braceIndent - 1),
-                         );
-                $phpcsFile->addError($error, $scopeEnd, 'Indent', $data);
+        $lineStart   = $phpcsFile->findFirstOnLine(T_WHITESPACE, $scopeEnd, true);
+        $braceIndent = $tokens[$lineStart]['column'];
+        if ($tokens[$stackPtr]['code'] !== T_DEFAULT
+            && $tokens[$stackPtr]['code'] !== T_CASE
+            && $braceIndent !== $startColumn
+        ) {
+            $error = 'Closing brace indented incorrectly; expected %s spaces, found %s';
+            $data  = array(
+                      ($startColumn - 1),
+                      ($braceIndent - 1),
+                     );
+
+            $fix = $phpcsFile->addFixableError($error, $scopeEnd, 'Indent', $data);
+            if ($fix === true) {
+                $diff = ($startColumn - $braceIndent);
+                if ($diff > 0) {
+                    $phpcsFile->fixer->addContentBefore($scopeEnd, str_repeat(' ', $diff));
+                } else {
+                    $phpcsFile->fixer->substrToken(($scopeEnd - 1), 0, $diff);
+                }
             }
-        }
+        }//end if
 
     }//end process()
 
 
 }//end class
-
-?>
