@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Zend_Sniffs_Files_ClosingTagSniff implements PHP_CodeSniffer_Sniff
@@ -38,7 +38,7 @@ class Zend_Sniffs_Files_ClosingTagSniff implements PHP_CodeSniffer_Sniff
      */
     public function register()
     {
-        return array(T_CLOSE_TAG);
+        return array(T_OPEN_TAG);
 
     }//end register()
 
@@ -54,31 +54,30 @@ class Zend_Sniffs_Files_ClosingTagSniff implements PHP_CodeSniffer_Sniff
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
+        // Find the last non-empty token.
         $tokens = $phpcsFile->getTokens();
-
-        $next = $phpcsFile->findNext(T_INLINE_HTML, ($stackPtr + 1), null, true);
-        if ($next !== false) {
-            return;
+        for ($last = ($phpcsFile->numTokens - 1); $last > 0; $last--) {
+            if (trim($tokens[$last]['content']) !== '') {
+                break;
+            }
         }
 
-        // We've found the last closing tag in the file so the only thing
-        // potentially remaining is inline HTML. Now we need to figure out
-        // whether or not it's just a bunch of whitespace.
-        $content = '';
-        for ($i = ($stackPtr + 1); $i < $phpcsFile->numTokens; $i++) {
-            $content .= $tokens[$i]['content'];
-        }
-
-        // Check if the remaining inline HTML is just whitespace.
-        $content = trim($content);
-        if (empty($content) === true) {
+        if ($tokens[$last]['code'] === T_CLOSE_TAG) {
             $error = 'A closing tag is not permitted at the end of a PHP file';
-            $phpcsFile->addError($error, $stackPtr, 'NotAllowed');
+            $fix   = $phpcsFile->addFixableError($error, $last, 'NotAllowed');
+            if ($fix === true) {
+                $phpcsFile->fixer->replaceToken($last, '');
+            }
+
+            $phpcsFile->recordMetric($stackPtr, 'PHP closing tag at EOF', 'yes');
+        } else {
+            $phpcsFile->recordMetric($stackPtr, 'PHP closing tag at EOF', 'no');
         }
 
+        // Ignore the rest of the file.
+        return ($phpcsFile->numTokens + 1);
+
     }//end process()
 
 
 }//end class
-
-?>
