@@ -24,7 +24,7 @@ if (class_exists('PHP_CodeSniffer_Tokenizers_PHP', true) === false) {
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.4
+ * @version   Release: 2.3.3
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
@@ -47,83 +47,83 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
             echo "\t*** START CSS TOKENIZING ***".PHP_EOL;
         }
 
-        // If the content doesn't have an EOl char on the end, add one so
+        // If the content doesn't have an EOL char on the end, add one so
         // the open and close tags we add are parsed correctly.
-        if (substr($string, 0, (strlen($eolChar) * -1)) !== $eolChar) {
-            $string .= $eolChar;
+        $eolAdded = false;
+        if (substr($string, (strlen($eolChar) * -1)) !== $eolChar) {
+            $string  .= $eolChar;
+            $eolAdded = true;
         }
 
-        $tokens      = parent::tokenizeString('<?php '.$string.'?>', $eolChar);
-        $finalTokens = array();
+        $string = str_replace('<?php', '^PHPCS_CSS_T_OPEN_TAG^', $string);
+        $string = str_replace('?>', '^PHPCS_CSS_T_CLOSE_TAG^', $string);
+        $tokens = parent::tokenizeString('<?php '.$string.'?>', $eolChar);
 
-        $newStackPtr      = 0;
+        $finalTokens    = array();
+        $finalTokens[0] = array(
+                           'code'    => T_OPEN_TAG,
+                           'type'    => 'T_OPEN_TAG',
+                           'content' => '',
+                          );
+
+        $newStackPtr      = 1;
         $numTokens        = count($tokens);
         $multiLineComment = false;
-        for ($stackPtr = 0; $stackPtr < $numTokens; $stackPtr++) {
+        for ($stackPtr = 1; $stackPtr < $numTokens; $stackPtr++) {
             $token = $tokens[$stackPtr];
 
-            // CSS files don't have lists or break tags, so convert these to
+            // CSS files don't have lists, breaks etc, so convert these to
             // standard strings early so they can be converted into T_STYLE
             // tokens and joined with other strings if needed.
-            if ($token['code'] === T_BREAK || $token['code'] === T_LIST) {
+            if ($token['code'] === T_BREAK
+                || $token['code'] === T_LIST
+                || $token['code'] === T_DEFAULT
+            ) {
                 $token['type'] = 'T_STRING';
                 $token['code'] = T_STRING;
             }
 
             if (PHP_CODESNIFFER_VERBOSITY > 1) {
                 $type    = $token['type'];
-                $content = str_replace($eolChar, '\n', $token['content']);
+                $content = PHP_CodeSniffer::prepareForOutput($token['content']);
                 echo "\tProcess token $stackPtr: $type => $content".PHP_EOL;
             }
 
-            // Sometimes, there are PHP tags embedded in the code, which causes issues
-            // with how PHP tokenizeses the string. After the first closing tag is found,
-            // everything outside PHP tags is set as inline HTML tokens (1 for each line).
-            // So we need to go through and find these tokens so we can re-tokenize them.
-            if ($token['code'] === T_CLOSE_TAG && $stackPtr !== ($numTokens - 1)) {
-                $content = '<?php ';
-                for ($x = ($stackPtr + 1); $x < $numTokens; $x++) {
-                    if ($tokens[$x]['code'] === T_INLINE_HTML) {
-                        $content .= $tokens[$x]['content'];
-                    } else {
-                        $x--;
+            if ($token['code'] === T_POWER
+                && $tokens[($stackPtr + 1)]['content'] === 'PHPCS_CSS_T_OPEN_TAG'
+            ) {
+                $content = '<?php';
+                for ($stackPtr = ($stackPtr + 3); $stackPtr < $numTokens; $stackPtr++) {
+                    if ($tokens[$stackPtr]['code'] === T_POWER
+                        && $tokens[($stackPtr + 1)]['content'] === 'PHPCS_CSS_T_CLOSE_TAG'
+                    ) {
+                        // Add the end tag and ignore the * we put at the end.
+                        $content  .= '?>';
+                        $stackPtr += 2;
                         break;
+                    } else {
+                        $content .= $tokens[$stackPtr]['content'];
                     }
                 }
 
-                if ($x < ($numTokens - 1)) {
-                    // This is not the last closing tag in the file, so we
-                    // have to add another closing tag here. If it is the last closing
-                    // tag, this additional one would have been added during the
-                    // original tokenize call.
-                    $content .= ' ?>';
-                }
-
                 if (PHP_CODESNIFFER_VERBOSITY > 1) {
-                    echo "\t\t=> Found premature closing tag at $stackPtr".PHP_EOL;
-                    $cleanContent = str_replace($eolChar, '\n', $content);
-                    echo "\t\tcontent: $cleanContent".PHP_EOL;
-                    $oldNumTokens = $numTokens;
+                    echo "\t\t=> Found embedded PHP code: ";
+                    $cleanContent = PHP_CodeSniffer::prepareForOutput($content);
+                    echo $cleanContent.PHP_EOL;
                 }
 
-                // Tokenize the string and remove the extra PHP tags we don't need.
-                $moreTokens = parent::tokenizeString($content, $eolChar);
-                array_shift($moreTokens);
-                array_pop($moreTokens);
-                array_pop($moreTokens);
+                $finalTokens[$newStackPtr] = array(
+                                              'type'    => 'T_EMBEDDED_PHP',
+                                              'code'    => T_EMBEDDED_PHP,
+                                              'content' => $content,
+                                             );
 
-                // Rebuild the tokens array.
-                array_splice($tokens, ($stackPtr + 1), ($x - $stackPtr), $moreTokens);
-                $numTokens = count($tokens);
-                if (PHP_CODESNIFFER_VERBOSITY > 1) {
-                    $count = count($moreTokens);
-                    $diff  = ($x - $stackPtr);
-                    echo "\t\t* added $count tokens, replaced $diff; size changed from $oldNumTokens to $numTokens *".PHP_EOL;
-                }
+                $newStackPtr++;
+                continue;
             }//end if
 
             if ($token['code'] === T_GOTO_LABEL) {
-                // Convert these back to T_STRING folowed by T_COLON so we can
+                // Convert these back to T_STRING followed by T_COLON so we can
                 // more easily process style definitions.
                 $finalTokens[$newStackPtr] = array(
                                               'type'    => 'T_STRING',
@@ -166,13 +166,26 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                 || $token['content']{0} === '#')
             ) {
                 $content = ltrim($token['content'], '#/');
-                $commentTokens
-                    = parent::tokenizeString('<?php '.$content.'?>', $eolChar);
+
+                // Guard against PHP7+ syntax errors by stripping
+                // leading zeros so the content doesn't look like an invalid int.
+                $leadingZero = false;
+                if ($content{0} === '0') {
+                    $content     = '1'.$content;
+                    $leadingZero = false;
+                }
+
+                $commentTokens = parent::tokenizeString('<?php '.$content.'?>', $eolChar);
 
                 // The first and last tokens are the open/close tags.
                 array_shift($commentTokens);
                 array_pop($commentTokens);
 
+                if ($leadingZero === true) {
+                    $commentTokens[0]['content'] = substr($commentTokens[0]['content'], 1);
+                    $content = substr($content, 1);
+                }
+
                 if ($token['content']{0} === '#') {
                     // The # character is not a comment in CSS files, so
                     // determine what it means in this context.
@@ -237,7 +250,7 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                 continue;
             }//end if
 
-            if ($token['code'] === T_COMMENT 
+            if ($token['code'] === T_COMMENT
                 && substr($token['content'], -2) === '*/'
             ) {
                 // Multi-line comment is done.
@@ -249,20 +262,33 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
         }//end for
 
         // A flag to indicate if we are inside a style definition,
-        // which is defined using curly braces. I'm assuming you can't
-        // have nested curly brackets.
+        // which is defined using curly braces.
         $inStyleDef = false;
 
+        // A flag to indicate if an At-rule like "@media" is used, which will result
+        // in nested curly brackets.
+        $asperandStart = false;
+
         $numTokens = count($finalTokens);
         for ($stackPtr = 0; $stackPtr < $numTokens; $stackPtr++) {
             $token = $finalTokens[$stackPtr];
 
             switch ($token['code']) {
             case T_OPEN_CURLY_BRACKET:
-                $inStyleDef = true;
+                // Opening curly brackets for an At-rule do not start a style
+                // definition. We also reset the asperand flag here because the next
+                // opening curly bracket could be indeed the start of a style
+                // definition.
+                if ($asperandStart === true) {
+                    $inStyleDef    = false;
+                    $asperandStart = false;
+                } else {
+                    $inStyleDef = true;
+                }
                 break;
             case T_CLOSE_CURLY_BRACKET:
-                $inStyleDef = false;
+                $inStyleDef    = false;
+                $asperandStart = false;
                 break;
             case T_MINUS:
                 // Minus signs are often used instead of spaces inside
@@ -271,29 +297,21 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                     if ($finalTokens[($stackPtr - 1)]['code'] === T_STRING) {
                         $newContent = $finalTokens[($stackPtr - 1)]['content'].'-'.$finalTokens[($stackPtr + 1)]['content'];
 
-                        $finalTokens[($stackPtr - 1)]['content'] = $newContent;
+                        $finalTokens[($stackPtr + 1)]['content'] = $newContent;
                         unset($finalTokens[$stackPtr]);
-                        unset($finalTokens[($stackPtr + 1)]);
-                        $stackPtr -= 2;
+                        unset($finalTokens[($stackPtr - 1)]);
                     } else {
                         $newContent = '-'.$finalTokens[($stackPtr + 1)]['content'];
 
                         $finalTokens[($stackPtr + 1)]['content'] = $newContent;
                         unset($finalTokens[$stackPtr]);
-                        $stackPtr--;
                     }
-
-                    $finalTokens = array_values($finalTokens);
-                    $numTokens   = count($finalTokens);
                 } else if ($finalTokens[($stackPtr + 1)]['code'] === T_LNUMBER) {
                     // They can also be used to provide negative numbers.
                     $finalTokens[($stackPtr + 1)]['content']
                         = '-'.$finalTokens[($stackPtr + 1)]['content'];
                     unset($finalTokens[$stackPtr]);
-
-                    $finalTokens = array_values($finalTokens);
-                    $numTokens   = count($finalTokens);
-                }
+                }//end if
 
                 break;
             case T_COLON:
@@ -303,7 +321,7 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                 }
 
                 for ($x = ($stackPtr - 1); $x >= 0; $x--) {
-                    if (in_array($finalTokens[$x]['code'], PHP_CodeSniffer_Tokens::$emptyTokens) === false) {
+                    if (isset(PHP_CodeSniffer_Tokens::$emptyTokens[$finalTokens[$x]['code']]) === false) {
                         break;
                     }
                 }
@@ -315,7 +333,7 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                 if (strtolower($token['content']) === 'url') {
                     // Find the next content.
                     for ($x = ($stackPtr + 1); $x < $numTokens; $x++) {
-                        if (in_array($finalTokens[$x]['code'], PHP_CodeSniffer_Tokens::$emptyTokens) === false) {
+                        if (isset(PHP_CodeSniffer_Tokens::$emptyTokens[$finalTokens[$x]['code']]) === false) {
                             break;
                         }
                     }
@@ -327,7 +345,7 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
 
                     // Make sure the content isn't empty.
                     for ($y = ($x + 1); $y < $numTokens; $y++) {
-                        if (in_array($finalTokens[$y]['code'], PHP_CodeSniffer_Tokens::$emptyTokens) === false) {
+                        if (isset(PHP_CodeSniffer_Tokens::$emptyTokens[$finalTokens[$y]['code']]) === false) {
                             break;
                         }
                     }
@@ -362,6 +380,9 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                     }
                 }//end if
 
+                break;
+            case T_ASPERAND:
+                $asperandStart = true;
                 break;
             default:
                 // Nothing special to be done with this token.
@@ -369,6 +390,28 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
             }//end switch
         }//end for
 
+        // Reset the array keys to avoid gaps.
+        $finalTokens = array_values($finalTokens);
+        $numTokens   = count($finalTokens);
+
+        // Blank out the content of the end tag.
+        $finalTokens[($numTokens - 1)]['content'] = '';
+
+        if ($eolAdded === true) {
+            // Strip off the extra EOL char we added for tokenizing.
+            $finalTokens[($numTokens - 2)]['content'] = substr(
+                $finalTokens[($numTokens - 2)]['content'],
+                0,
+                (strlen($eolChar) * -1)
+            );
+
+            if ($finalTokens[($numTokens - 2)]['content'] === '') {
+                unset($finalTokens[($numTokens - 2)]);
+                $finalTokens = array_values($finalTokens);
+                $numTokens   = count($finalTokens);
+            }
+        }
+
         if (PHP_CODESNIFFER_VERBOSITY > 1) {
             echo "\t*** END CSS TOKENIZING ***".PHP_EOL;
         }
@@ -381,19 +424,19 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
     /**
      * Performs additional processing after main tokenizing.
      *
-     * @param array  &$tokens The array of tokens to process.
+     * @param array  $tokens  The array of tokens to process.
      * @param string $eolChar The EOL character to use for splitting strings.
      *
      * @return void
      */
     public function processAdditional(&$tokens, $eolChar)
     {
-        // We override this method because we don't want the PHP version to
-        // run during CSS processing because it is wasted processing time.
+        /*
+            We override this method because we don't want the PHP version to
+            run during CSS processing because it is wasted processing time.
+        */
 
     }//end processAdditional()
 
 
 }//end class
-
-?>
